package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@(!`0D```````````(`/@`!````\!]```````!``````````##*````
M`````````$``.``'`$``&@`9``8````%````0`````````!``$```````$``
M0```````B`$```````"(`0````````@``````````P````0```#(`0``````
M`,@!0```````R`%````````5`````````!4``````````0`````````!````
M!0````````````````!``````````$```````$2T````````1+0`````````
M`!````````$````&`````,``````````P%````````#`4```````(`@`````
M```H#0``````````$````````@````8`````Q`````````#$4````````,10
M``````#P`0```````/`!````````"``````````$````!````.`!````````
MX`%```````#@`4```````!@`````````&``````````$`````````%#E=&0$
M````/+0````````\M$```````#RT0```````"``````````(``````````0`
M````````+VQI8F5X96,O;&0M96QF+G-O+C$`````"`````0````!````1G)E
M94)31`!K-0P`80```&@````````````````````)`````````%T```!<````
M6```````````````9@````````!%````6P`````````X````0````#L````.
M````-P```$D```!0````1@```&4``````````````"(```!9````+P````$`
M````````,@```%(````M````80`````````&````&P```&(````<````````
M`"L`````````8````!`````N````7P````````!+````*0````4```!.````
M9````#X```!"````)@```%4````9````9P`````````Q````(0````````!(
M`````````````````````````%$```!$````-0```%<```!>````'P``````
M`````````````%8````S````00```%0```!:````#0`````````/````!```
M`````````````````#D`````````(````!0`````````+````&,`````````
M````````````````````````````````````````````````````````````
M``````````P`````````````````````````````````````````````````
M`````````````!@`````````$@````,````:````"```````````````"P``
M`````````````````````````````````````````````````"H`````````
M'@`````````*````(P`````````E``````````````````````````(`````
M````````````````````-@``````````````/0``````````````````````
M```Z```````````````D````'0````<````H`````````!$````G````````
M```````_`````````#P```!-````,```````````````-````!<```!,````
M0P`````````3`````````!8```!3````3P``````````````2@```!4`````
M`````````$<`````````````````````````````````````````#````!(`
M```,'$```````(T`````````Y@(``!(````<'$```````)``````````%P``
M`!(````L'$```````)T(````````*0```!$`%P`@R%````````$`````````
M=P,``!(````\'$````````\`````````R0,``!(`#`!P/T```````+X!````
M````0````!$`\?\`Q%````````````````````,``!(```!,'$``````````
M````````#0,``!(```!<'$```````#0`````````,P,``!(```!L'$``````
M`%4`````````20```!(```!\'$```````/``````````5P```!(```",'$``
M`````.0`````````8P```!(```"<'$````````\!````````U@,``!(`#``P
M/$````````4`````````=````!$`%P`HR%````````@`````````YP,``!$`
M$``8P%````````@`````````AP(``!$`%P`PR%```````$``````````?@``
M`!(```"L'$```````*H'````````C0```!$`%P!PR%````````@`````````
M\0,``!(`#`"`.$```````$T`````````EP```!(```"\'$````````H#````
M````_P,``!(`#`!@04```````.(`````````00,``!(```#,'$````````(`
M````````[@(``!(```#<'$```````"$`````````)`,``!(```#L'$``````
M`/4,````````I0```!$`%P!XR%````````$`````````,`0``!(`"@#H&T``
M````````````````L@```!(```#\'$```````&$%````````O0```!(````,
M'4```````)``````````R@```!(````<'4```````&$!````````V````!$`
M%P`@S5````````@`````````X````!(````L'4```````,4"````````%0,`
M`!(````\'4```````$P`````````'0,``!(```!,'4``````````````````
M"P0``!(`#`"P1$```````*P!````````ZP```!(```!<'4```````&<`````
M````&`0``!(`#`"04$```````%(#````````+@0``!(`#`#P4T```````!0`
M````````+`,``!(```!L'4````````P`````````]0(``!$`$```P%``````
M``@`````````F0,``!(`#`#P'T```````)P`````````:0,``!(```!\'4``
M`````````````````0,``!(```",'4``````````````````2P,``!(```"<
M'4````````H`````````.@,``!(```"L'4```````%0`````````-@0``!(`
M#`!@1D```````"P*````````^@```!(```"\'4```````#L$````````P0(`
M`!(```#,'4``````````````````70(``!(```#<'4```````#$`````````
MSP(``!(```#L'4```````&<`````````0P0``!(`#`!00D```````&T`````
M````!@,``!(```#\'4```````'P``````````P$``!$`%P!YR%````````$`
M````````4P,``!(````,'D```````'X`````````$0$``!(````<'D``````
M`,X!````````(0$``!$`%P"`R%````````@`````````E`,``!``\?\@R%``
M````````````````;P(``!(````L'D```````$,`````````3P0``!(`#`#`
M0D```````/`!````````5`0``!(`#`!0/D```````!<!````````9@0``!(`
M#`!@.T```````,D`````````,0$``!$`%P"(R%````````$`````````/`$`
M`!(`#0!H5$``````````````````0@$``!(````\'D```````!\:````````
MMP0``!(```!,'D```````!X`````````:@(``!(```!<'D```````)0`````
M````?P(``!(```!L'D```````$H`````````4`$``!(```!\'D```````$(`
M````````9`,``!(```",'D```````"\`````````AP,``!(```"<'D``````
M````````````&P(``!(```"L'D```````#P&````````8`$``!(```"\'D``
M`````"L`````````C0,``!``\?\@R%``````````````````H`(``!(```#,
M'D```````$H`````````:P$``!$`\?\8QE``````````````````H`,``!``
M\?\HS5``````````````````QP(``!(```#<'D```````&P`````````@0$`
M`!$`%P")R%````````$`````````C`$``!$`%P"0R%```````!,`````````
MIP(``!$`%P"HR%````````@`````````)P(``!(```#L'D```````&\)````
M````N@(``!(```#\'D``````````````````?`0``!(`#`#0.$```````!X`
M````````FP$``!(````,'T```````'P`````````U0(``!(````<'T``````
M``P`````````F`0``!(`#```(4```````#0`````````L@$``!$`%P"PR%``
M``````@`````````8@,``!(````L'T```````"\`````````I00``!(`#``P
M04```````"(`````````N`$``!$`%P"XR%````````@`````````F0(``!(`
M```\'T``````````````````PP$``!(```!,'T```````)$"````````T0$`
M`!$`%P#`R%````````@`````````<`,``!(```!<'T```````,<`````````
M?@,``!(```!L'T```````)L`````````90(``!(```!\'T```````&<`````
M````W@$``"``````````````````````````6@,``!(```",'T```````"T!
M````````\@$``!(```"<'T```````!4`````````L0(``!(```"L'T``````
M``````````````(``!(```"\'T```````&@!````````#P(``!(```#,'T``
M`````#8`````````(@(``!(```#<'T```````!4``````````&QI8G!E<FPN
M<V\`4&5R;%]C<F]A:P!097)L7W-V7S)P=E]F;&%G<P!03%]P97)L7V1E<W1R
M=6-T7VQE=F5L`%]$64Y!34E#`%!E<FQ?879?<VAI9G0`4&5R;%]M9U]S970`
M4&5R;%]N97=84U]F;&%G<P!03%]C;VUP8W8`<&5R;%]C;VYS=')U8W0`4$Q?
M<&%R<V5R`%!E<FQ?9&]U;G=I;F0`4$Q?9&]?=6YD=6UP`'!E<FQ?<&%R<V4`
M4&5R;%]N97=35G!V`%!E<FQ?<W9?<V5T<'8`96YV:7)O;@!097)L7VYE=UA3
M`%!E<FQ?<WES7VEN:70S`'!E<FQ?<G5N`%!,7V5X:71?9FQA9W,`8F]O=%]$
M>6YA3&]A9&5R`%!,7V-U<G-T86-K:6YF;P!03%]T86EN=&5D`%]F:6YI`'!E
M<FQ?9&5S=')U8W0`4&5R;%]G=E]F971C:'!V`'!E<FQ?86QL;V,`7T=,3T)!
M3%]/1D93151?5$%"3$5?`%!,7VEN7V5V86P`4$Q?;65M;W)Y7W=R87``4&5R
M;%]S879E7V1E<W1R=6-T;W)?>`!03%]O<`!03%]T;W!?96YV`%!E<FQ?879?
M9F5T8V@`4$Q?979A;%]R;V]T`%]*=E]296=I<W1E<D-L87-S97,`4&5R;%]S
M>7-?=&5R;0!097)L7W-V7W-E='!V;@!097)L7W-A9F5S>7-M86QL;V,`<&5R
M;%]F<F5E`&QI8FTN<V\N-0!L:6)C<GEP="YS;RXU`&QI8G5T:6PN<V\N.`!L
M:6)T:'(N<V\N,P!?7V5R<F]R`')E860`;W!E;@!C;&]S90!L:6)C+G-O+C<`
M;65M;6]V90!?7W-T86-K7V-H:U]G=6%R9`!G971P:60`;65M8W!Y`%]?<W1D
M97)R<`!R96%D;&EN:P!G971U:60`<FUD:7(`<F5A9&1I<@!L<V5E:P!?7W-T
M86-K7V-H:U]F86EL`&9P<FEN=&8`;65M8VAR`%]?<')O9VYA;64`;'-T870`
M<W1R<W1R`'-T<FYC;7``<W1R;F-P>0!U;FQI;FL`<F5A;&QO8P!S=')T;VL`
M<W1R9'5P`&UE;7-E=`!?:6YI=%]T;',`;W!E;F1I<@!S=')C;7``<W!R:6YT
M9@!A=&5X:70`86-C97-S`'-T<FQE;@!E>&5C=G``8VQO<V5D:7(`;6MD:7(`
M7V5D871A`%]?8G-S7W-T87)T`%]E;F0`+W5S<B]L;V-A;"]L:6(O<&5R;#4O
M-2XQ-"]M86-H+T-/4D4`<&%R7VEN:71?96YV`'!A<E]C=7)R96YT7V5X96,`
M;7E?<&%R7W!L`'!A<E]E;G9?8VQE86X`<&%R7V1I<FYA;64`<&%R7V9I;F1P
M<F]G`%A37TEN=&5R;F%L<U]005)?0D]/5`!X<U]I;FET`'!A<E]M:W1M<&1I
M<@!P87)?8VQE86YU<`!M86EN`'!A<E]S971U<%]L:6)P871H`'!A<E]C=7)R
M96YT7V5X96-?<')O8P!84U]);G1E<FYA;'-?4$%27T-,14%24U1!0TL`<&%R
M7V)A<V5N86UE`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`$9"4T1?,2XP
M`````````@```````@`!``$``@`"``(``````````0````$``@```````0``
M``$``@`"``(````!``````````$````"``(``0````$``0`"``$``0`"``(`
M`@`"``$````"``,``@`!``(````"```````!``,``0`!``$````!`````@`#
M``(````"``(``@````$``@`!``$``@```````@`"``(``0````(``0````(`
M`0````(```````(``@`#`````@````(``````````````````0`!`%$"```0
M````(````+`H>@<```,`P`0````````!``$`=0(``!``````````L"AZ!P``
M`@#`!````````"#(4```````!0````0``````````````"C(4```````!0``
M``\``````````````##(4```````!0```!$``````````````'#(4```````
M!0```!,``````````````'C(4```````!0```!H``````````````'G(4```
M````!0```#4``````````````(#(4```````!0```#@``````````````(C(
M4```````!0```#X``````````````(G(4```````!0```$X`````````````
M`)#(4```````!0```$\``````````````*C(4```````!0```%``````````
M`````+#(4```````!0```%<``````````````+C(4```````!0```%H`````
M`````````,#(4```````!0```%T``````````````##&4```````!P````$`
M`````````````#C&4```````!P````(``````````````$#&4```````!P``
M``,``````````````$C&4```````!P````4``````````````%#&4```````
M!P````@``````````````%C&4```````!P````D``````````````&#&4```
M````!P````H``````````````&C&4```````!P````L``````````````'#&
M4```````!P````P``````````````'C&4```````!P````T`````````````
M`(#&4```````!P```!(``````````````(C&4```````!P```!4`````````
M`````)#&4```````!P```!<``````````````)C&4```````!P```!@`````
M`````````*#&4```````!P```!D``````````````*C&4```````!P```!P`
M`````````````+#&4```````!P```!T``````````````+C&4```````!P``
M`!X``````````````,#&4```````!P```"```````````````,C&4```````
M!P```"$``````````````-#&4```````!P```"(``````````````-C&4```
M````!P```"0``````````````.#&4```````!P```"<``````````````.C&
M4```````!P```"H``````````````/#&4```````!P```"L`````````````
M`/C&4```````!P```"P```````````````#'4```````!P```"T`````````
M``````C'4```````!P```"\``````````````!#'4```````!P```#``````
M`````````!C'4```````!P```#$``````````````"#'4```````!P```#(`
M`````````````"C'4```````!P```#0``````````````##'4```````!P``
M`#8``````````````#C'4```````!P```#<``````````````$#'4```````
M!P```#H``````````````$C'4```````!P```$```````````````%#'4```
M````!P```$$``````````````%C'4```````!P```$(``````````````&#'
M4```````!P```$,``````````````&C'4```````!P```$0`````````````
M`'#'4```````!P```$4``````````````'C'4```````!P```$8`````````
M`````(#'4```````!P```$<``````````````(C'4```````!P```$@`````
M`````````)#'4```````!P```$H``````````````)C'4```````!P```$T`
M`````````````*#'4```````!P```%$``````````````*C'4```````!P``
M`%(``````````````+#'4```````!P```%0``````````````+C'4```````
M!P```%4``````````````,#'4```````!P```%@``````````````,C'4```
M````!P```%L``````````````-#'4```````!P```%P``````````````-C'
M4```````!P```%X``````````````.#'4```````!P```%\`````````````
M`.C'4```````!P```&```````````````/#'4```````!P```&(`````````
M`````/C'4```````!P```&,```````````````#(4```````!P```&0`````
M``````````C(4```````!P```&4``````````````!#(4```````!P```&8`
M`````````````!C(4```````!P```&<``````````````$B#[`CHWP0``.A*
M.```2(/$",,`_S4>JA``_R4@JA``D)"0D/\E'JH0`&@`````Z>#_____)1:J
M$`!H`0```.G0_____R4.JA``:`(```#IP/____\E!JH0`&@#````Z;#_____
M)?ZI$`!H!````.F@_____R7VJ1``:`4```#ID/____\E[JD0`&@&````Z8#_
M____)>:I$`!H!P```.EP_____R7>J1``:`@```#I8/____\EUJD0`&@)````
MZ5#_____)<ZI$`!H"@```.E`_____R7&J1``:`L```#I,/____\EOJD0`&@,
M````Z2#_____);:I$`!H#0```.D0_____R6NJ1``:`X```#I`/____\EIJD0
M`&@/````Z?#^____)9ZI$`!H$````.G@_O___R66J1``:!$```#IT/[___\E
MCJD0`&@2````Z<#^____)8:I$`!H$P```.FP_O___R5^J1``:!0```#IH/[_
M__\E=JD0`&@5````Z9#^____)6ZI$`!H%@```.F`_O___R5FJ1``:!<```#I
M</[___\E7JD0`&@8````Z6#^____)5:I$`!H&0```.E0_O___R5.J1``:!H`
M``#I0/[___\E1JD0`&@;````Z3#^____)3ZI$`!H'````.D@_O___R4VJ1``
M:!T```#I$/[___\E+JD0`&@>````Z0#^____)2:I$`!H'P```.GP_?___R4>
MJ1``:"````#IX/W___\E%JD0`&@A````Z=#]____)0ZI$`!H(@```.G`_?__
M_R4&J1``:",```#IL/W___\E_J@0`&@D````Z:#]____)?:H$`!H)0```.F0
M_?___R7NJ!``:"8```#I@/W___\EYJ@0`&@G````Z7#]____)=ZH$`!H*```
M`.E@_?___R76J!``:"D```#I4/W___\ESJ@0`&@J````Z4#]____)<:H$`!H
M*P```.DP_?___R6^J!``:"P```#I(/W___\EMJ@0`&@M````Z1#]____):ZH
M$`!H+@```.D`_?___R6FJ!``:"\```#I\/S___\EGJ@0`&@P````Z>#\____
M)9:H$`!H,0```.G0_/___R6.J!``:#(```#IP/S___\EAJ@0`&@S````Z;#\
M____)7ZH$`!H-````.F@_/___R5VJ!``:#4```#ID/S___\E;J@0`&@V````
MZ8#\____)6:H$`!H-P```.EP_/___R5>J!``:#@```#I8/S___\E5J@0`&@Y
M````Z5#\____)4ZH$`!H.@```.E`_/___R5&J!``:#L```#I,/S___\E/J@0
M`&@\````Z2#\____)3:H$`!H/0```.D0_/__`````%5(B>5!54R-;PA!5%-(
M@^P(BQ](8\.%VTR-9,<03(DE#*T0`'XZ2(M7"$B%TG0Q2(D5VI\0``^V`H3`
M="-(@\(!/"](BP7&GQ``2`]$PDB)!;N?$``/M@)(@\(!A,!UX;@`Q%``2(7`
M="M(B??HRO[__[]H5$``Z,#^___H=_O__XG?3(GB3(GNZ$(B``")Q^@'_O__
MZ$+\___KUI"0D)!(@^P(@#TMJ!```'00ZR202(/`"$B)!66?$`#_TDB+!5R?
M$`!(BQ!(A=)UY,8%!:@0``%(@\0(PV9F9I!F9F:02(,].*40``!T%K@`````
M2(7`=`R_$,90`$F)PT'_XY#SPY"0D)"0D)"0D)"0D)"0#[8/2(GXA,ET*$B+
M!=<U``!(C5<!#[8P2(GX9F:09I!`./$/M@I(#T3"2(/"`83)=>[SPV9F9I!F
M9F:09F9FD$%62(UW.$%505152(G]4TB![`@"``!,C4PDB$V-@8````!,B<](
MBPY(@\8(2(G*2(G(2,'B"$C!X!@E````_X'B``#_`$@)PDB)R$C!Z`@E`/\`
M`$@)PDB)R$C!Z!@E_P```$@)PDB)R$C!Z2A(P>@@2(D72,'@"$B)PDC!X!`E
M````_X'B``#_`$@)PDB)R$C!Z1`E`/\``$@)PD@)RDB)5PA(@\<03#G'#X5U
M____28U):$F-L6@"``!F9I!FD$B+`4@S0=A(,T&H2#-!F$B)PD@!P$C!ZA](
M"<*#XO](B5$82(/!"$@Y\7743(MU`$B+?"2(0;W<O!N/2`-]($B+30A,BU40
M2(MU&$R)\$R)\DV)\4C!X@5(P>@;28G(2`G03(G22<'H`H/@_T@ARDG!Z0)(
MC;P'F7F"6DB)R$C!X1Y(]]!)"<A((?!!@^#_2`-T))!("=!,B<(!QTR)\$PA
M\DCWT$B)^4PAT$C!Z1M,`U0DF$@)PDB)^$C!X`5(C;06F7F"6DB)^D@)P4R)
M\$C!X!X!\4D)P4B)^$B)SD&#X?](]]!(P>X;3"'*3"'`2`G02(G*38V4`IEY
M@EI(B<A(P>`%2`G&2(G(1`'628GZ2/?02<'J`DC!YQY,`T0DH$D)^DPAR$B)
M]T&#XO](P>\;3`-,)*A,(=)("=!(B?)-C80`F7F"6DB)\$C!X`5("<=(B?!$
M`<=)B<A(P>$>2<'H`DCWT$D)R$PAT$B)^4&#X/](P>D;3`-4)+!,(<)("=!(
MB?I-C8P!F7F"6DB)^$C!X`5("<%(B?A$`<E)B?%(P>8>2<'I`DCWT$D)\4PA
MP$B)SD&#X?](P>X;3"'*2`G02(G*38V4`IEY@EI(B<A(P>`%3`-$)+A("<9(
MB<A$`=9)B?I(P><>2<'J`DCWT$D)^DPAR$B)]T&#XO](P>\;3`-,),!,(=)(
M"=!(B?)-C80`F7F"6DB)\$C!X`5("<=(B?!$`<=)B<A(P>$>2<'H`DCWT$D)
MR$PAT$B)^4&#X/](P>D;3`-4),A,(<)("=!(B?I-C8P!F7F"6DB)^$C!X`5(
M"<%(B?A$`<E)B?%(P>8>2<'I`DCWT$D)\4PAP$B)SD&#X?],(<I(P>X;3`-$
M)-!("=!(B<I-C90"F7F"6DB)R$C!X`5("<9(B<A$`=9)B?I(P><>2<'J`DCW
MT$D)^DPAR$B)]T&#XO](P>\;3`-,)-A,(=)("=!(B?)-C80`F7F"6DB)\$C!
MX`5("<=(B?!$`<=)B<A(P>$>2<'H`DCWT$D)R$PAT$B)^4&#X/](P>D;3"'"
M2`G02(GZ38V,`9EY@EI(B?A(P>`%2`G!2(GX1`')28GQ2,'F'DG!Z0)(]]!)
M"?%(B<Y!@^'_3`-4).!,(<!,(<I(P>X;3`-$).A("=!(B<I-C90"F7F"6DB)
MR$C!X`5("<9(B<A$`=9)B?I(P><>2<'J`DCWT$D)^DPAR$B)]T&#XO](P>\;
M3`-,)/!,(=)("=!(B?)-C80`F7F"6DB)\$C!X`5("<=(B?!$`<=)B<A(P>$>
M2<'H`DCWT$D)R$PAT$B)^4&#X/](P>D;3"'"2`G02(GZ38V,`9EY@EI(B?A(
MP>`%2`G!2(GX1`')28GQ2/?02<'I`DC!YAY,`U0D^$D)\4PAP$B)SD&#X?](
MP>X;3`,$)$PARD@)T$B)RDV-E`*9>8):2(G(2,'@!4@)QDB)R$0!UDF)^DC!
MYQY)P>H"2/?028GS20GZ3"'(2(GW08/B_TC![QM,`TPD"$PATD@)T$B)\DV-
MA`"9>8):2(GP2,'@!4@)QTB)\$0!QTF)R$C!X1Y)P>@"2/?020G(3"'02(GY
M08/@_TC!Z1M,(<)("=!(B?I-C8P!F7F"6DB)^$C!X`5(P>8>2<'K`DP#5"00
M2`G!20GS2(GX08/C_T0!R4CWT$PAVDB)SDPAP$F)^4C![AM("=!(P><>2<'I
M`DV-E`*9>8):2(G(3`-$)!A(P>`%20GY2(G*2`G&2(G(08/A_TCWT$PARD0!
MUDPAV$B)]TF)RD@)T$C!X1Y(P>\;38V$`)EY@EI(B?!)P>H"2,'@!4P#7"0@
M20G*2`G'2(GP08/B_TB)\DCWT$0!QTPAR$F)\$PATD@)T$C!YAY)P>@"38V<
M`YEY@EI)"?!(B?I(B?A!@^#_3`-,)"A(P>`%2,'J&T@)PDR)P$PQT$0!VDP#
M5"0P2#'X2(G138V,`:'KV6Y(B=!(P>D;2,'@!4@)P40!R4F)^4C!YQY)P>D"
M2(G.20GY2(G72,'N&T&#X?](P>\"3(G(3#'`3`-$)#A(,=!(P>(>38V4`J'K
MV6Y("==(B<B#Y_](P>`%2`G&2(GX1`'63#'(3`-,)$!(,<A(B?)-C80`H>O9
M;DB)\$C!ZAM(P>`%2`G"1`'"28G(2,'A'DG!Z`))"<A(B=%!@^#_2,'I&TR)
MP$@Q^$@#?"1(2#'P38V,`:'KV6Y(B=!(P>`%2`G!1`')28GQ2,'F'DG!Z0))
M"?%(B<Y!@^'_2,'N&TR)R$PQP$P#1"102#'02(V\!Z'KV6Y(B<A(P>`%2`G&
M`?Y(B==(P>(>2,'O`D@)UTB)\H/G_TB)^$PQR$C!ZAM,`TPD6$@QR$V-A`"A
MZ]EN2(GP2,'@!4@)PD0!PDF)R$C!X1Y)P>@"20G(2(G108/@_TC!Z1M,B<!(
M,?A(`WPD8$@Q\$V-C`&AZ]EN2(G02,'@!4@)P40!R4F)\4C!YAY)P>D"20GQ
M2(G.08/A_TC![AM,B<A,,<!,`T0D:$@QT$B-O`>AZ]EN2(G(2,'@!4@)Q@'^
M2(G72,'B'DC![P)("==(B?*#Y_](B?A,,<A(P>H;3`-,)'!(,<A-C80`H>O9
M;DB)\$C!X`5("<)$`<))B<A(P>$>2<'H`DD)R$B)T4&#X/](P>D;3(G`2#'X
M2`-\)'A(,?!-C8P!H>O9;DB)T$C!X`5("<%$`<E)B?%(P>8>2<'I`DD)\4B)
MSD&#X?](P>X;3(G(3#'`3`.$)(````!(,=!(C;P'H>O9;DB)R$C!X`5("<8!
M_DB)UTC!XAY(P>\"2`G72(GR@^?_2(GX3#'(2,'J&TP#C"2(````2#'(38V$
M`*'KV6Y(B?!(P>`%2`G"1`'"28G(2,'A'DG!Z`))"<A(B=%!@^#_2,'I&TR)
MP$@Q^$@#O"20````2#'P38V,`:'KV6Y(B=!(P>`%2`G!1`')28GQ2,'F'DG!
MZ0))"?%(B<Y!@^'_2,'N&TR)R$PQP$P#A"28````2#'02(V\!Z'KV6Y(B<A(
MP>`%2`G&`?Y(B==(P>(>2,'O`D@)UTB)\H/G_TB)^$PQR$C!ZAM,`XPDH```
M`$@QR$V-A`"AZ]EN2(GP2,'@!4@)PD0!PDF)R$C!X1Y)P>@"28G220G(2(G1
M2<'J`D&#X/](P>D;3(G`2#'X2`.\)*@```!(,?!-C8P!H>O9;DB)T$C!X`5(
M"<%$`<E)B?%(P>8>2<'I`DF)S$D)\4B)SD&#X?](P>X;3(G(3#'`3`.$)+``
M``!(,=!(P>(>2(V\!Z'KV6Y)"=)(B<A!@^+_2,'@!4@)QDR)T`'^3#'(2<'L
M`D@QR$C!X1Y(B?)-C80`H>O9;DD)S$B)\$&#Y/],`XPDN````$C!X`5(P>H;
M2(GS2(N,),@```!("<),B>!(P>L"3#'01`'"3`.4),````!(,?!(P>8>2(G7
M38V,`:'KV6Y("?-(B="#X_](P>`%2,'O&T@)QTB)V$F)TTPQX$0!STG!ZP)(
M,=!(P>(>28GX38V4`J'KV6Y)"=-(B?A!@^/_2,'@!4G!Z!M)"<!,`>E,B=A%
M`=!,B=I,`>%("=A((=I,B<9((?A)B?E(P>X;2`G02,'G'DG!Z0)(`<%,B<!)
M"?E(P>`%08/A_TV)PD@)QDR)R$R)R@'.2(N,)-````!,"=A,(=I,(<!(B?=(
M"=!(P>\;2<'@'DP!Z4G!Z@)!O-;!8LI(`=E-"<)(`<%(B?!!@^+_2,'@!4R)
MTD@)QTR)T`'/2(N,)-@```!,"<A((?!)B?A,`>E,`=E,(<I)B?-("=!(P>8>
M2<'H&T@!P4B)^$G!ZP)(P>`%20GS20G`08/C_T$!R$B+C"3@````3(G83`G0
M3(G:3(G&3"'22"'X2,'N&TP!Z4@)T$P!R4F)^4C!YQY(`<%,B<!)P>D"2,'@
M!4D)^4@)QD&#X?\!SDB+C"3H````3(G(3`G83(G*2(GW3"':3"'`3`'I2`G0
M3`'138G"2`'!2(GP2,'O&TC!X`5)P>`>2<'J`D@)QTT)P@'/08/B_TB+C"3P
M````3(G03(G228GX3`G(3"'*2<'H&TP!Z4@A\$@)T$P!V4F)\T@!P4B)^$C!
MYAY(P>`%2<'K`DD)P$D)\T$!R$&#X_](BXPD^````$R)V$R)VDR)QDP)T$PA
MTDC![AM,`>E((?A("=!,`<E)B?E(`<%,B<!(P>`%2`G&`<Y(P><>2<'I`DD)
M^4B+C"0``0``2(GW08/A_TC![QM,B<A,B<I,"=A,(=I,`>E,(<!,`=%-B<)(
M"=!)P>`>2<'J`D@!P4B)\$T)PDC!X`5!@^+_2`G'3(G03(G2`<](BXPD"`$`
M`$P)R$PARD@A\$F)^$@)T$G!Z!M,`>E,`=E)B?-(P>8>2`'!2(GX2<'K`DC!
MX`5)"<!!`<A)"?-(BXPD$`$``$&#X_],B<9,B=A,B=I(P>X;3`G03"'23`'I
M2"'X3`')28GY2`G02,'G'DG!Z0)(`<%,B<!)"?E(P>`%08/A_T@)QDR)R$R)
MR@'.2(N,)!@!``!,"=A,(=I,(<!(B?=("=!(P>\;3`'I3`'138G"2<'@'D@!
MP4B)\$G!Z@)(P>`%30G"2`G'08/B_P'/2(N,)"`!``!,B=!,B=))B?A,`>E,
M`=E,"<A,(<I((?!)B?-)P>@;2`G02,'F'DG!ZP)(`<%(B?A)"?-(P>`%08/C
M_TD)P$R)V$R)VD$!R$B+C"0H`0``3`G03"'22"'X3(G&2`G02,'N&TP!Z4P!
MR4F)^4C!YQY(`<%,B<!)P>D"2,'@!4D)^4@)QD&#X?\!SDB+C"0P`0``3(G(
M3`G83(G*2(GW3"'`3`'I3`'13"':38G"2`G02<'@'DC![QM(`<%(B?!)P>H"
M2,'@!4T)PD@)QT&#XO\!STB+C"0X`0``3(G03`G(3(G228GX3"'*2"'P2<'H
M&TP!Z4@)T$P!V4F)\TC!YAY(`<%(B?A)P>L"2,'@!4D)\TD)P$&#X_]!`<A(
MBXPD0`$``$R)V$P)T$R)VDR)QDPATD@A^$P!Z4@)T$P!R4F)^4@!P4R)P$C!
M[AM(P>`%2,'G'DG!Z0)("<9)"?D!SD&#X?](BXPD2`$``$R)R$R)RDB)]TP)
MV$PAVDC![QM,`>E,(<!("=!,`=%-B<)(`<%(B?!)P>`>2,'@!4G!Z@)("<=-
M"<(!ST&#XO](BXPD4`$``$R)T$R)TDF)^$P)R$PARDG!Z!M,`>E((?!("=!,
M`=E)B?-(`<%(B?A(P>`%20G`00'(2,'F'DG!ZP))"?-(BXPD6`$``$R)QD&#
MX_](P>X;3(G83(G:3`'I3`G03"'23`')2"'X28GY2`G02,'G'DG!Z0)(`<%)
M"?E,B<!!@^'_3`.L)&`!``!(P>`%2`G&3(G(3(G*3`G83"':`<Y,(<!(B?=(
M"=!-`=5(P>\;20'%2(GP38G"2,'@!4G!X!Y)P>H"2`G'2(N4)&@!``!$`>]-
M"<))B?!!@^+_2(GY2<'H`DR)T$P!XDC!Z1M,,<A,`=I(,?!(P>8>2`'"2(GX
M20GP2,'@!4&#X/]("<%,B<`!T4B+E"1P`0``3#'02#'X2(G.2,'N&TP!XDP!
MRDF)^4C!YQY(`<)(B<A)P>D"2,'@!4D)^4@)QD&#X?\!UDB+E"1X`0``3(G(
M3#'`2(GW2#'(3`'B3`'228G*2`'"2(GP2,'O&TC!X`5(P>$>2<'J`D@)QTD)
MR@'72(N4)(`!``!!@^+_3(G02(GY3#'(2,'I&TP!XD@Q\$P!PDF)\$C!YAY(
M`<)(B?A)P>@"2,'@!4D)\$@)P4&#X/\!T4B+E"2(`0``3(G`3#'02(G.2#'X
M2,'N&TP!XDP!RDF)^4C!YQY(`<)(B<A)P>D"2,'@!4D)^4@)Q@'62(N4))`!
M``!!@^'_3(G(2(GW3#'`2,'O&TP!XD@QR$P!TDF)RDC!X1Y(`<)(B?!)P>H"
M2,'@!4D)RD@)QT&#XO\!UTB+E"28`0``3(G03#'(2(GY2#'P2,'I&TP!XDP!
MPDF)\$C!YAY(`<)(B?A)P>@"2,'@!4D)\$@)P4&#X/\!T4B+E"2@`0``3(G`
M3#'02(G.2#'X2,'N&TP!XDP!RDF)^4@!PDB)R$C!X`5(P><>2<'I`D@)QDD)
M^0'62(N4)*@!``!!@^'_3(G(2(GW3#'`2,'O&TP!XD@QR$P!TDF)RDC!X1Y(
M`<)(B?!)P>H"2,'@!4D)RD@)QT&#XO\!UTB+E"2P`0``3(G03#'(2(GY2#'P
M2,'I&TP!XDP!PDF)\$C!YAY(`<)(B?A)P>@"2,'@!4D)\$@)P4&#X/\!T4B+
ME"2X`0``3(G`2(G.3`'B3#'02,'N&T@Q^$P!RDF)^4@!PDB)R$C!YQY(P>`%
M2<'I`D@)QDD)^0'62(N4),`!``!!@^'_3(G(2(GW3#'`2,'O&TP!XD@QR$P!
MTDF)RDC!X1Y(`<)(B?!)P>H"2,'@!4D)RD@)QT&#XO\!UTB+E"3(`0``3(G0
M3#'(2(GY2#'P2,'I&TP!XDP!PDF)\$@!PDB)^$C!X`5("<%(P>8>2<'H`@'1
M20GP2(N4)-`!``!!@^#_2(G.3(G`2,'N&TP!XDPQT$@Q^$P!RDF)^4@!PDB)
MR$C!YQY(P>`%2<'I`D@)QDD)^0'62(N4)-@!``!!@^'_3(G(2(GW28GS3#'`
M2,'O&TP!XD@QR$P!TDF)RDC!X1Y(`<)(B?!)P>H"2,'@!4D)RD@)QT&#XO\!
MUTB+E"3@`0``3(G02(GY2(G[3`'B3`'"3#'(2,'I&T@Q\$G!ZP)(P>8>2`'"
M2(GX20GS2,'@!4&#X_](P>L"2`G!3(G8`=%(BY0DZ`$``$PQT$@Q^$F)R$C!
MYQY)P>@;2`G[3`'B@^/_3`'*28G)2`'"2(G(2,'@!4D)P$B)V$$!T$B+E"3P
M`0``3#'82#'(3(G'3(G&2,'O&TP!XDP!TD@!PDR)P$C!X`5("<<!UTC!X1Y)
MP>D"20G)2(N4)/@!``!(P>X"08/A_TB)^4R)R$C!Z1M,`>)(,=A,`Z0D``(`
M`$PQP$P!VDG!X!Y(`<),"<9(B?A(P>`%@^;_2`G!2(GP20'<3#'(`=%(,?A(
MB<I)`<1(B<A(P>(%2,'H&T@)T$0!X$0!\$B)10!(B?A(P><>2,'H`@--"$@)
M^`-%$`-U&$0#32!(B4T(2(E%$$B)=1A,B4T@2('$"`(``%M=05Q!74%>PTR)
M9"3@3(E\)/A)B?Q(B5PDT$B);"3828GW3(EL).A,B70D\$B#[#A(A?]U)3'`
M2(M<)`A(BVPD$$R+9"083(ML)"!,BW0D*$R+?"0P2(/$.,-,BS67E1``387V
M=,\/M@>$P'4$,<#K%SP]2(GZ=/5(@\(!#[8"A,!U18G01"G@28LN2(7M=*5,
M8^A,B?-FD$R)ZDR)YDB)[^B.Y/__A<!U"DF-1"T`@#@]=!I(BVL(2(/#"$B%
M[777Z6____]FD#P]=:SKM4PI\TB#P`%(P?L#08D?Z5;___]F9F:09F:055-(
MB?M(@^P82(UL)!1FD#'`2(GN2(G?Z`/___](A<!T)DAC1"042(T4Q0````!(
M`Q7:E!``2(/""$B+`DB%P$B)0OAU\.O(2(/$&%M=PY!(@^P8,<!(C70D%.C`
M_O__2(/$&,-F9F:09F9FD&9FD$B#[`B#/96'$`#_=`N+!8V'$`!(@\0(PS'`
MO\E40`#HO/___TB%P'0'#[8`A,!U$S'`B05HAQ``BP5BAQ``2(/$",,\,`^5
MP`^VP.OE9F:02(/L"+______Z-[C__\Q]K_P.$``2(/$".D>YO__9I!(BP6)
MCQ``4S'VOV960`!(BT@(2(L%IH\0``^W4"`/M@5TCQ``9H'B_P&#X'_!X@<)
MPF:)40)(BP53CQ``2(M8".C6X___2(E#*$B+!3^/$`!(BU`(2(L%=(\0`$B)
M0C!(BP4ICQ``,=)(BT@(2(L%#(\0`$B%P'0'2(N0J````$B)43A(BP4%CQ``
M2(M`"$C'0$``````2(L%\HX0`$B+0`A(QT`@`````$B+!=^.$`!(BU`(2(L%
M#(\0`$B)0DA;PV9F9I!F9F:09F:09F:03(ED).A(B5PDV$F)_$B);"3@3(EL
M)/!,B70D^$B![*@```!(A?]T!8`_`'4S2(N<)(````!(BZPDB````$R+I"20
M````3(NL))@```!,B[0DH````$B!Q*@```##9F:0Z'?C__](A<!(B<5TP&9F
MD$B)[^BDY/__2(7`#X2A````2(U8"+_45$``N0(```#\2(G>\Z9TV;_35$``
MN0,```!(B=[SIG3(3(GGZ.SD__](B=])B<7HX>3__T&-1`4"2&/XZ"3D__](
MB=E(B<=)B<5,B>*^UE1``#'`Z.SD__](B>9,B>_HX>+__X/``701#[=$)`@E
M`/```#T`0```=#9,B>_H@^+__TR)[^@;Y/__2(GOZ`/D__](A<`/A5____](
MB>_H@N3__TR)Y^C:XO__Z?;^__],B>_HP?[__Y#KQV9F9I!F9F:09F:09F:0
M4TB)^TB#Q(!(B>;H+.'__X7`=1@/MT0D""4`\```/0!```!T#ST`H```=`A(
M@^R`,<!;PTB)W[X"````Z"OB__^%P`^4P$B#[(!;#[;`PY!(B5PDZ$B);"3P
M3(ED)/A(@>PX"```2(V<)!`$``!(BP6KC!``2(F$)!@(```QP.BHX___N7I6
M0`")PK[<5$``,<!(B=_HXN/__X7`>38Q[4B+E"08"```2#,5<8P0`$B)Z'5@
M2(N<)"`(``!(BZPD*`@``$R+I"0P"```2('$.`@``,-(B=^Z``0``$B)YNBX
MX___A<")PWBTC7@!2&/_Z*?B__](A<!TI$ACVTB)Q4B)YDB)VDB)Q^BNXO__
MQ@0K`.N,Z//B__]F9F:09F:0Z2O___]F9F:09F9FD&9FD$%7,<!!5DF)_D%5
M05152(GU4TB#[!B`/CT/E,!(`<5(B>_H]>+__TB-="0408G'3(GW,<#HM_K_
M_TB%P$B)PW0W2(G'Z-/B__]$B?I(.=`/@KP````/MD4`2(/%`8@#2(/#`83`
M=>Y(@\08,<!;74%<05U!7D%?PTB+/6&0$`!%,>2X$````$B#/P!T'TB)^DB+
M0@A!@\0!2(/""$B%P'7O08U$)`)(F$C!X`.+%>Z+$`"%T@^%$`$``$B)Q\<%
MV8L0``$```#HH.'__TB%P$F)Q0^$&0$``$ECQ$B+-?Z/$`!,B>](C1S%````
M`$B)VN@WX?__3(DMY(\0`$B+!=V/$`!(QT0#"`````!$B60D%$$/MA9,B?"$
MT@^%B````(M<)!1%*?=!C7P'`DC!XP-(`QVICQ``Z##A__](A<!(B0,/A*D`
M``"+5"042(L%C8\0`$B+%-!!#[8&A,"(`G0E/#UT(4R)]^L.9F:09F:02(/'
M`3P]=`X/MD<!2(/"`83`B`)UZL8"/69F9I!F9I`/MD4`2(/%`8A"`4B#P@&$
MP'7MZ;_^__^`^CT/A&____](@\`!#[8(A,D/A&#___^`^3UU[.E6____2(G&
M9F:0Z-?>__](A<!(B04!CQ``=!!)8\1(C1S%`````.D+____2(/$&+C_____
M6UU!7$%=05Y!7\-F9F:09F9FD&9FD$%7059)B?Y!54%40;SR5$``55-(@^Q(
M3(L]@A@``$F)Y4C'!"3R5$``2,=$)`CH5$``2,=$)!#U5$``2,=$)!CK5$``
M2,=$)"#P5$``2,=$)"@"54``2,=$)#``````ZQY,B?9,B><QP.B"_?__38ME
M"$F#Q0A-A>0/A(D````QP$R)Y^B'^?__2(7`2(G%=-"`.`!TRTR)]DB)Q^@+
MW___2(7`=<A,B??H7N#__TR)_TB)P^A3X/__2(U<`P%(B>_H1N#__TB-/`/H
MC=___TF)Z$B)QTB)PTR)^4R)\KXA5D``,<#H4N#__TR)YS'`2(G>Z/G\__]-
MBV4(28/%"$V%Y`^%=____TB#Q$A;74%<05U!7D%?PV9FD&9FD&9FD$B#[#B_
M#55``$B+!;"($`!(B40D*#'`2(L%,A<``$B)!"1(BP4O%P``2(E$)`A(BP4K
M%P``2(E$)!!(BP4G%P``2(E$)!@/MP4C%P``9HE$)"`QP.A'^/__,<"_%E5`
M`.@[^/__,<"_'E5``.@O^/__,<"_)U5``.@C^/__,<"_+E5``.@7^/__,<"_
M/E5``.@+^/__,<"_2E5``.C_]___,<"_R51``.CS]___,<"_4U5``.CG]___
M,<"_755``.C;]___,<"_9U5``.C/]___,<"_=%5``.C#]___,<"_?55``.BW
M]___,<"_B%5``.C[]___2(7`=`](B<:_4U5``#'`Z,?[__\QP+^954``Z-OW
M__](A<!T#TB)QK^K54``,<#HI_O__S'`O[950`#HN_?__TB%P'0V2(G&OTI5
M0``QP.B'^___,<"^XE5``+\N54``Z';[__](BT0D*$@S!5J'$`!U44B#Q#C#
M9F:0,<"_QE5``.AT]___2(7`=!%(B<:_R51``#'`Z$#[___KMTB-="01O]=5
M0`"Y"@```/SSIG6C2(UT)!N_R51``#'`Z!G[___KD.CNW?__9I!(@^P(Z,/=
M__^)Q^@,W?__,=)(A<!T`TB+$$B)T$B#Q`C#9F9FD&9F9I!F9I!F9I!54TB)
M^TB#[`A(A?]T"`^V+T"$[7402(/$"+_45$``6UWIYMK__^C1W?__2`'82(U0
M_T@YTP^#G@```$B+/485```/MD#_#[8W0#CP=`GK*@^V"CC!=69(@^H!2#G3
M9I!R[D@YVG4I0#HO=*I(@\0(6UWIE=K__P^V`D`XQG3C2(/J`4@YTW+OZ]AF
M9I!F9I!(@^H!2#G3<PD/M@(Z!V:0=.Y(*=HQR4B-0@)(/0`$``!V#DB#Q`A(
MB<A;7<.)R.NY2(/"`4B)WK\`R5``Z`K;__^Y`,E0`.O:2(L]J!0``.N`9F9F
MD&9F9I!F9I!F9I!(B5PD\$B);"3X2(/L&$B)^^CZ_O__2(G'Z)+>__](B<4Q
MP.@(]O__A<!T"DB%VW0%@#L`=0](BUPD"$B+;"002(/$&,.^Y%5``$B)[^A:
MV___2#G%==](B=](BVPD$$B+7"0(2(/$&.D#]___9F:04TB#["")?"0<2(ET
M)!!(C7PD'$B)5"0(2(UT)!!(C50D".AUVO__@#V*A1````^$*0$``(M$)!R`
M#7J%$``#@\`%2&/(2(7)#XA*`0``\D@/*L'R#U@%O7```&8/+@6]<```#X=,
M`0``2(T\S0````#HEMS__TB+="002(G!2(D%TXD0`$R-2?A(BP9(QT$(Z55`
M`$B)`4B+!;I\$`!(QT$8[%5``$B)01!$BT0D',<%EXD0``0```!!@_@!?B9,
MC4GXOP$```"Z"````&9FD$B+!!:#QP%(B40*&$B#P@A!.?A_ZT&-0`2^$%1`
M`$4QP$B82<<$P0````"+5"0<2(L].HD0`(/"`^@NV?__A<")PW1Q2(L])8D0
M`.A<VO__,<"_/E5``.AT]/__2(7`=!E(BST(B1``Z-_;___HFMO__XG82(/$
M(%O#2(L]]X@0`$B%_W1PZ#7^___KU&9FD.B7VO__2(7`2(G'2(D%SH@0`'1T
MZ'/8___&!>"#$```Z:_^__](BSVTB!``Z&O9__^)P^E\____2(G(2(G*2-'H
M@^(!2`G0\D@/*L#R#UC`Z9[^__^^D,A0`+_E5$``,<#HAM?__[]*54``Z-#S
M__](A<!(B<=(B05KB!``#X5S____Z4G___]`MP'HW-G__T%7059!54%428G\
MOTI50`!54TB)\TB![*@$``!(BP5=@Q``2(F$))@$```QP.A^\___2(LM_Q$`
M`$R)YTF)Q4B)[N@%V?__2(7`=#E,B>:_9U5``#'`Z#7W__](BY0DF`0``$@S
M%1:#$`!,B>`/A30!``!(@<2H!```6UU!7$%=05Y!7\-,B>?H']K__TR+/:P1
M``!(B=]!B<9,B?[H&MC__TB%P$B)PW2B08/&`42)="0,3(VT))````!F9I!F
MD(`[`+C45$``2`]$V$V%[70/2(G>3(GOZ(#8__^%P'1^2(G?Z,39__^)P4B8
M#[9$`_\Z10!U'8U!_TB82(T4&)`/MD+_Q@(`@^D!2(/J`3I%`'3MBT0D#`'(
M/?\#```/CRC___]-B>!(B>E(B=J^(59``$R)]S'`Z*#9__](C70D$$R)]^B3
MU___A<!U$0^W1"08)0#P```]`(```'0;,?],B?[H5-?__TB%P$B)PP^%3/__
M_^G3_O__O@$```!,B??H1M?__X7`==1,B?:_9U5``.CY]?__3(GWZ!W6__])
MB<3IM/[__^C`V/__9F9FD$%728G_OTI50`!!5D%505154TB![.B!``!(BP6P
M@1``2(F$)-B!```QP$C'A"30````[U5``$C'A"38````]%5``$C'A"3@````
M`````.BM\?__2(7`2(G#=`F`.``/A8\"```QP$B-K"30````Z%WZ__](A<!(
MB<,/A,<!``!(B=_H==C__TB-?``!Z+O7__^`.P!)B<5T)DB)Q69F9I`/MA-(
MB>\QP+X$5D``2(/#`4B#Q0+H<MC__X`[`'7A2(VL)*````"_JU5``$C'A"2@
M````JU5``$C'A"2H````I%5``$C'A"2P````"59``$C'A"2X````P55``$C'
MA"3`````$59``$C'A"3(`````````.L12(M]"$B#Q0A(A?\/A$X!```QP.C2
M\/__2(7`2(G#=."`.`!TVTB)Q^AM\___A<!TSTB)W^B]U/__2(7`28G$#X0=
M`0``3(GGZ)G7__],B>](B</HCM?__XV$`P0$``!(8^A(B>_HS-;__TB+%0$/
M``!(B<=)B<9-B>E!N.150`"^'U9``#'`2(G12(E4)!!,B>+H?]?__[[``0``
M3(GWZ(+6__^#P`$/A$@!``!(C70D($R)]^@<U/__A<!U%0^W1"0H)0#P```]
M`$````^$6`$``$F+%TB+/56`$`!,B?&^.%=``#'`,>WHN-/__TB+E"38@0``
M2#,5O7\0`$B)Z`^%<P(``$B!Q.B!``!;74%<05U!7D%?PTB)Q^C6T___2(G#
M2(/%"$B%VP^%.?[__TB+?0!(A?\/A#("```QP.BF[___2(7`=-J`.`!URDB#
MQ0A(A=MTV69FD.D*_O__13'D@#TV#0```$C'A"3P````%59``+L55D``2,>$
M)/@```#45$``2,>$)``!````````2(VL)/````!U*.FD_O__387D#X6;_O__
M2(M="$B%VP^$CO[__TB#Q0B`.P`/A('^__](B=_HSO'__X7`=-%(B=_H'M/_
M_TF)Q.O$2(G'Z/7T__](B=_H"=/__TB)Q>GY_O__Z&S4__^#.!$/A*K^___H
M7M3__TF+%T2+`$R)\4B+/1I_$`"^^%9``#'`,>WH@-+__^G#_O__BUPD+.A2
MU?__.<,/A9?^__\/MT0D*"7_`0``/<`!```/A8+^__](B>_HW=3__[_K5$``
M2(G%,<#H@N[__TB%P$B)QP^$"P$``.A]TO__28L_2(G&Z+;Z__](A<!)B<0/
MA.\```!,B>?H3M7__X/X`T&)P`^/904``#'`Z%_N__^%P'46,?9,B>?H+=3_
M_X7`B40D'`^%P@```+[B54``O\E40``QP.CT\?__Z.O4__](BTPD$$&)P$&Y
M9E9``$R)\KY!5D``2(GO,<`QV^@9U?__ZSKH8M/__X,X$69FD'4_Z+74__](
MBTPD$(/#`4&)P$&)V4R)\KY/5D``2(GO,<!(QP0D9E9``.C=U/__OL`!``!(
MB>_HX-/__X/``72T3(GWZ"/4__](B>Z_2E5``#'`Z&CQ__](B>_H<//__^E_
M_?__N_U50`#I\/O__Y#H)]3__TV+)^D)____N@(```!(Q\;N____B<?HW-+_
M_XM\)!Q(C;0D$`$``+H&````Z%;4__^`O"00`0```'4.@+PD$0$``$,/A-@$
M``"+?"0<,?8QTDR-I"00@0``Z)G2__^_B:O-[[[^W+J8N?#ATL-(QX0D$($`
M``$C16=(B;PD&($``$F#Q#A(B;0D(($``$C'A"0H@0``=E0R$$B)C"0P@0``
M2,>$)#B!````````2,>$)$"!````````QX0DB($```````"+?"0<2(VT)!`!
M``"Z`(```.BMT___A<!!B<4/CCH!``!(BXPD.($``$ECU4B+A"1`@0``2(V<
M)!`!``"---%(.<Y(B;0D.($``$B#T`!(P>H=2(F$)$"!``!(`90D0($``(N4
M)(B!``"%TG1IZ84```!F9I!FD$B+`TB-O"00@0``08/M0$B)A"1(@0``2(M#
M"$F)1"0(2(M#$$F)1"002(M#&$F)1"082(M#($F)1"0@2(M#*$F)1"0H2(M#
M,$F)1"0P2(M#.$B#PT!)B40D..BQU/__08/]/W^;26/52(G>3(GGZ"G2__]$
MB:PDB($``.D)____N$````!(8_I(C;0D$`$``"G028T\/$$YQ8G#00].W4QC
M^TR)^NCRT?__B=@#A"2(@0``@_A`B80DB($```^%QO[__TB-C"00`0``02G=
M2(V\)!"!``!)C1P/Z#'4___I>____XM\)!SH#]'__TB+G"0X@0``3(ND)$"!
M``!(B=A(P>@#@^`_2&/0@\`!@_@XQH042($``(`/CJ<"``!(8_BZ0````#'V
M*<)(C;P\2($``$ACTNA"T/__2(V\)!"!``#HR=/__TB-O"00@0``N0<````Q
MP/Q(@\<X\TBK3(G@2(V\)!"!``!$B*0D@X$``$C!Z!B(G"2'@0``3(V\))"!
M``"(A"2`@0``3(G@3(VL),"!``!(P>@0B(0D@8$``$R)X$V)_$C!Z`B(A"2"
M@0``2(G82,'H&(B$)(2!``!(B=A(P>@0B(0DA8$``$B)V#';2,'H"(B$)(:!
M``#H+=/__TB+E"00@0``2(G0B)0DPX$``$C!Z!B(A"3`@0``2(G02,'H$(B$
M),&!``!(B=!(BY0D&($``$C!Z`B(A"3"@0``2(G0B)0DQX$``$C!Z!B(A"3$
M@0``2(G02,'H$(B$),6!``!(B=!(BY0D(($``$C!Z`B(A"3&@0``2(G0B)0D
MRX$``$C!Z!B(A"3(@0``2(G02,'H$(B$),F!``!(B=!(BY0D*($``$C!Z`B(
MA"3*@0``2(G0B)0DSX$``$C!Z!B(A"3,@0``2(G02,'H$(B$),V!``!(B=!(
MBY0D,($``$C!Z`B(A"3.@0``2(G0B)0DTX$``$C!Z!B(A"30@0``2(G02,'H
M$(B$)-&!``!(B=!(P>@(B(0DTH$``$(/MA0K3(GG,<"^!%9``$B#PP%)@\0"
MZ$#0__](@_L4==[&A"2X@0```$&Y9E9``$V)^$B+3"003(GROC)60`!(B>\Q
MP.@2T/__Z4+[__](F+\H5D``28UT!/RX!0```/Q(B<'SI@^%?OK__T&#^`1T
M&4&-0/Q(BU0D$$B800^V1`3_.@(/A5_Z__])BU\(2(7;#X12^O__2(G?Z(S/
M__](@_@##X9`^O__2(UT`_R_+59``+D%````_/.F3`]$X^DE^O__NC@```!(
M8_@Q]BG"2(V\/$B!``!(8]+HF\W__^EX_?__@+PD$@$``$$/A1K[__^`O"03
M`0``0P^%#/O__X"\)!0!``!(#X7^^O__@+PD%0$``$4/A?#Z__^+?"0<N@(`
M``!(Q\;&____Z(G-__^+?"0<2(VT)!`!``"Z*0```.@#S___3(V$)!`!``!!
MN6960`#IU_[__V9F9I!!5K\N54``055!5%532('L$`0``,8%W7<0``%(BP5^
M=Q``2(F$)`@$```QP.B?Y___2(7`=`F`.#$/A-L!```QP.B:[O__N@L```"^
M`0```+]@5D``Z)+-__](A<`/A(,````Q[8,]%'P0``%(BT`03(M@*'Y?NP@`
M``#K+69FD$B+=Q!(BP7]>Q``2(L\&.CHS/__A<!U/8/%`4B#PPB-10$Y!=A[
M$`!^*S'2B>Y,B>?H!L[__TB%P'0:2(LX]D<-!'6\,?:Z`@```.C,RO__2(G&
MZZ^+%:5[$`"-0O\YZ`^$#@$``+H$````O@$```"_959``.CRS/__2(7`2(G#
M=")(BT`0OF=60`!(BSCH><O__TB+0Q!(BSCV1PY`#X4'`0``N@0```"^`0``
M`+^&54``Z+3,__](A<!(B<-T)S'`OV=50`#HA.;__TB%P$B)P@^$"`$``$B+
M0Q!(B=9(BSCH)<O__S'`OTI50`#&!8-V$```2,<%&'80``````#H2^;__TB%
MP$B)!>EZ$``/A*4```"^P`$``$B)Q^AJS/__A<!U)4B+A"0(!```2#,%ZW40
M``^%'P$``$B!Q!`$``!;74%<05U!7L.#^!%TUH/X_W31B<%(BP6J>A``2(L5
MDWH0`+_@5T``2(LP,<#HB,G__X/J`0^.Z?[__[L!````3(GG@\,!Z-_)__\Y
M'6UZ$`!_[>G,_O__@'@!`&:0#X0@_O__Z13^__]F9I!FD.C'R?__Z>K^__](
MBSU'>A``Z(KS__](A<!(B04H>A``#X6/````OY!70`#H',G__TB+!2%Z$`"Z
M_P,``$B)YK]L5D``3(LP2(M#$$R+*.B9S/__A<")PGXX@^H!2&/J@#PL`'5`
MA=)^*$B)ZKXO````2(GGZ*/)__](A<!T$TB)ZDB)YDR)[^APS/__Z:;^__],
MB?9,B>_HP,G__V9F9I#IDO[__TACZ.N_9F:09F:0Z*?+__](BT,02(LMF'D0
M`$B+./9'#01T.DB+?Q!(B>[HI\C__XG%2(M#$$B+./9'#01T,$B+1Q!(B<)(
MBP5F>1``B>F_N%=``$B+,#'`Z$G(__^Z`@```#'VZ%W(__](B<?KN;H"````
M,?;H3,C__^O&9F9FD&9F9I!F9I!F9I"Z?U9``+X<'D``OXE60`#I*,G__V9F
M9I!F9F:09F9FD$B#[`CHU____[EF5D``13'`OI!00`!(B<J_I59``$B#Q`CI
M9<C__Y"0D)"0D)"0D$B+!:EQ$`!32(/X_W05,=O_T$B+@^C%4`!(@^L(2(/X
M_W7M6\.0D)!(@^P(Z!_,__](@\0(PP``)$9R965"4T0Z(')E;&5A<V4O."XP
M+C`O;&EB+V-S=2]A;60V-"]C<G1I+E,@,3(W,C4R(#(P,#0M,#,M,C$@,#$Z
M,SDZ,#%:('!E=&5R("0`4$%27T-,14%.`"XN`"5S+R5S`"]P<F]C+R5I+R5S
M`$Q)0E!!5$@`1%E,1%],24)205)97U!!5$@`4TA,24)?4$%42`!015),-4Q)
M0@!015),3$E"`%!%4DPU3U!4`%!%4DQ)3P!005)?24Y)5$E!3$E:140`4$%2
M7U-005=.140`4$%27U1%35``4$%27T1%0E5'`%!!4E]#04-(10!005)?4%)/
M1TY!344`4$%27T%21T,`4$%27T%21U9?,`!005)?1TQ/0D%,7T1%0E5'`%!!
M4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]414U0`%!!
M4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q`'!A<BT`+64`+2T`55-%4@!5
M4T523D%-10!365-414T`)3`R>`!414U01$E2`%1-4``O=F%R+W1M<"\`)7,E
M<R5S)7,`<&%R;``N<&%R`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U)7,`
M)7,E<W1E;7`M)74M)74E<P!!4D=6`!@`<&5R;``O<')O8R]C=7)P<F]C+V9I
M;&4`<&5R;'AS:2YC`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E
M<FYA;',Z.E!!4CHZ0D]/5``Z``````!?7T5.5E]005)?0TQ%04Y?7R`@("`@
M("`@("`@("`@(```````````'59```````"Z5D```````"5S.B!C<F5A=&EO
M;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I
M*0H````````E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E
M("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*
M````````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`````````
M`"5S.B!E>&5C=71I;VX@;V8@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@
M8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I
M;&5D("AE<G)N;STE:2D*```````````C(2]U<W(O8FEN+W!E<FP*979A;"`G
M97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"B`@("!I9B`P
M.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*"G!A8VMA9V4@7U]P
M87)?<&P["@HC("TM+2!4:&ES('-C<FEP="!M=7-T(&YO="!U<V4@86YY(&UO
M9'5L97,@870@8V]M<&EL92!T:6UE("TM+0HC('5S92!S=')I8W0["@HC;&EN
M92`Q-3@*"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%
M3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["B`@("!R97%U:7)E($9I;&4Z
M.E1E;7`["B`@("!R97%U:7)E($9I;&4Z.D)A<V5N86UE.PH@("`@<F5Q=6ER
M92!&:6QE.CI3<&5C.PH@("`@;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE
M.CID:7)N86UE*"1P87)?=&5M<"D["B`@("!O=71S*'%Q>U)E;6]V:6YG(&9I
M;&5S(&EN("(D<&%R7W1E;7`B?2D["B`@("!&:6QE.CI&:6YD.CIF:6YD9&5P
M=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP
M*3L*("`@(')M9&ER("1P87)?=&5M<#L*("`@(",@1&]N)W0@<F5M;W9E('1O
M<&1I<B!B96-A=7-E('1H:7,@8V%U<V5S(&$@<F%C92!W:71H(&]T:&5R(&%P
M<',*("`@(",@=&AA="!A<F4@=')Y:6YG('1O('-T87)T+@H*("`@(&EF("@M
M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PH@("`@("`@(",@
M4V]M971H:6YG('=E;G0@=W)O;F<@=6YL:6YK:6YG('1H92!T96UP;W)A<GD@
M9&ER96-T;W)Y+B`@5&AI<PH@("`@("`@(",@='EP:6-A;&QY(&AA<'!E;G,@
M;VX@<&QA=&9O<FUS('1H870@9&ES86QL;W<@=6YL:6YK:6YG('-H87)E9`H@
M("`@("`@(",@;&EB<F%R:65S(&%N9"!E>&5C=71A8FQE<R!T:&%T(&%R92!I
M;B!U<V4N(%5N;&EN:R!W:71H(&$@8F%C:V=R;W5N9`H@("`@("`@(",@<VAE
M;&P@8V]M;6%N9"!S;R!T:&4@9FEL97,@87)E(&YO(&QO;F=E<B!I;B!U<V4@
M8GD@=&AI<R!P<F]C97-S+@H@("`@("`@(",@1&]N)W0@9&\@86YY=&AI;F<@
M;VX@5VEN9&]W<R!B96-A=7-E(&]U<B!P87)E;G0@<')O8V5S<R!W:6QL"B`@
M("`@("`@(R!T86ME(&-A<F4@;V8@8VQE86YI;F<@=&AI;F=S('5P+@H*("`@
M("`@("!M>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"B`@("`@("`@("`@(%1%
M35!,051%(#T^("=T;7!86%A86"<L"B`@("`@("`@("`@($1)4B`]/B!&:6QE
M.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*("`@("`@("`@("`@4U5&
M1DE8(#T^("<N8VUD)RP*("`@("`@("`@("`@54Y,24Y+(#T^(#`L"B`@("`@
M("`@*3L*"B`@("`@("`@<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI
M;&4@6R!<)'@@+6QT(#$P(%T[(&1O"B`@(')M("UR9B`G)'!A<E]T96UP)PH@
M("!I9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*("`@("`@(&)R96%K
M"B`@(&9I"B`@('-L965P(#$*("`@>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M
M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PH@("`@("`@("`@("!C:&UO
M9"`P-S`P+"1T;7`M/F9I;&5N86UE.PH@("`@("`@(&UY("1C;60@/2`D=&UP
M+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PH@("`@("`@(&-L
M;W-E("1T;7`["B`@("`@("`@<WES=&5M*"1C;60I.PH@("`@("`@(&]U=',H
M<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A
M;G5P.B`I"B`@("`@("`@("`@("`N("1T;7`M/F9I;&5N86UE*3L*("`@('T*
M?2!]"@I"14=)3B!["B`@("!);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E
M9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PH*("`@(&5V86P@>PH*7W!A
M<E]I;FET7V5N=B@I.PH*:68@*&5X:7-T<R`D14Y6>U!!4E]!4D=67S!](&%N
M9"`D14Y6>U!!4E]!4D=67S!]("D@>PH@("`@0$%21U8@/2!M87`@)$5.5GLB
M4$%27T%21U9?)%\B?2P@*#$@+BX@)$5.5GM005)?05)'0WT@+2`Q*3L*("`@
M("0P(#T@)$5.5GM005)?05)'5E\P?3L*?0IE;'-E('L*("`@(&9O<B`H:V5Y
M<R`E14Y6*2!["B`@("`@("`@9&5L971E("1%3E9[)%]](&EF("]>4$%27T%2
M1U9?+SL*("`@('T*?0H*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*
M"B,@9FEX("1P<F]G;F%M92!I9B!I;G9O:V5D(&9R;VT@4$%42`IM>2`E0V]N
M9FEG(#T@*`H@("`@<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_
M("<[)R`Z("<Z)RDL"B`@("!?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z
M35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`H@("`@7V1E;&EM
M("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P*
M*3L*"E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PH*(R!-86=I
M8R!S=')I;F<@8VAE8VMI;F<@86YD(&5X=')A8W1I;F<@8G5N9&QE9"!M;V1U
M;&5S('M[>PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PH@("`@;&]C
M86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["@H@("`@(R!#:&5C:R!F:6QE
M('1Y<&4L(&=E="!S=&%R="!O9B!D871A('-E8W1I;VX@>WM["B`@("!O<&5N
M(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*("`@(&)I;FUO9&4H7T9(
M*3L*"B`@("!M>2`D8G5F.PH@("`@<V5E:R!?1D@L("TX+"`R.PH@("`@<F5A
M9"!?1D@L("1B=68L(#@["B`@("!L87-T('5N;&5S<R`D8G5F(&5Q(")<;E!!
M4BYP;5QN(CL*"B`@("!S965K(%]&2"P@+3$R+"`R.PH@("`@<F5A9"!?1D@L
M("1B=68L(#0["B`@("!S965K(%]&2"P@+3$R("T@=6YP86-K*").(BP@)&)U
M9BDL(#(["B`@("!R96%D(%]&2"P@)&)U9BP@-#L*"B`@("`D9&%T85]P;W,@
M/2`H=&5L;"!?1D@I("T@-#L*("`@(",@?7U]"@H@("`@(R!%>'1R86-T:6YG
M(&5A8V@@9FEL92!I;G1O(&UE;6]R>2![>WL*("`@(&UY("5R97%U:7)E7VQI
M<W0["B`@("!W:&EL92`H)&)U9B!E<2`B1DE,12(I('L*("`@("`@("!R96%D
M(%]&2"P@)&)U9BP@-#L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@=6YP86-K
M*").(BP@)&)U9BD["@H@("`@("`@(&UY("1F=6QL;F%M92`]("1B=68["B`@
M("`@("`@;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI
M.PH@("`@("`@(&UY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD
M77LX?2DO?'P@*2`_("0Q(#H@=6YD968["B`@("`@("`@;7D@*"1B87-E;F%M
M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PH*
M("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@("`@("!R96%D(%]&2"P@
M)&)U9BP@=6YP86-K*").(BP@)&)U9BD["@H@("`@("`@(&EF("AD969I;F5D
M*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PH@
M("`@("`@("`@("!M>2`H)&]U="P@)&9I;&5N86UE*2`](%]T96UP9FEL92@D
M97AT+"`D8W)C*3L*("`@("`@("`@("`@:68@*"1O=70I('L*("`@("`@("`@
M("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@("`@("!P<FEN="`D
M;W5T("1B=68["B`@("`@("`@("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@
M("`@("`@("`@8VAM;V0@,#<U-2P@)&9I;&5N86UE.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE
M?2`]("1F:6QE;F%M93L*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PH@("`@("`@('T*("`@("`@
M("!E;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN
M960@)$5.5GM005)?5$5-4'T@*2!["B`@("`@("`@("`@(",@<VAO=6QD(&)E
M(&UO=F5D('1O(%]T96UP9FEL92@I"B`@("`@("`@("`@(&UY("1F:6QE;F%M
M92`]("(D14Y6>U!!4E]414U0?2\D8F%S96YA;64D97AT(CL*("`@("`@("`@
M("`@;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["B`@("`@("`@("`@(&]P
M96X@;7D@)&]U="P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PH@("`@("`@
M("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@("!P<FEN="`D;W5T("1B
M=68["B`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@?0H@("`@("`@
M(&5L<V4@>PH@("`@("`@("`@("`D<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@
M/0H@("`@("`@("`@("`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN
M86UE?2`]('L*("`@("`@("`@("`@("`@(&)U9B`]/B`D8G5F+`H@("`@("`@
M("`@("`@("`@8W)C(#T^("1C<F,L"B`@("`@("`@("`@("`@("!N86UE(#T^
M("1F=6QL;F%M92P*("`@("`@("`@("`@?3L*("`@("`@("!]"B`@("`@("`@
M<F5A9"!?1D@L("1B=68L(#0["B`@("!]"B`@("`C('U]?0H*("`@(&QO8V%L
M($!)3D,@/2`H<W5B('L*("`@("`@("!M>2`H)'-E;&8L("1M;V1U;&4I(#T@
M0%\["@H@("`@("`@(')E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L
M93L*"B`@("`@("`@;7D@)&9I;&5N86UE(#T@9&5L971E("1R97%U:7)E7VQI
M<W1[)&UO9'5L97T@?'P@9&\@>PH@("`@("`@("`@("!M>2`D:V5Y.PH@("`@
M("`@("`@("!F;W)E86-H("AK97ES("5R97%U:7)E7VQI<W0I('L*("`@("`@
M("`@("`@("`@(&YE>'0@=6YL97-S("]<421M;V1U;&5<120O.PH@("`@("`@
M("`@("`@("`@)&ME>2`]("1?.R!L87-T.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H
M)&ME>2D["B`@("`@("`@?2!O<B!R971U<FX["@H@("`@("`@("1)3D-[)&UO
M9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["@H@("`@("`@
M(&EF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN
M97<I*2!["B`@("`@("`@("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP
M9FEL92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@
M("`@("`@("`@<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["B`@("`@("`@
M("`@('-E96LH)&9H+"`P+"`P*3L*("`@("`@("`@("`@<F5T=7)N("1F:#L*
M("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@(&UY("@D;W5T
M+"`D;F%M92D@/2!?=&5M<&9I;&4H)RYP;2<L("1F:6QE;F%M92T^>V-R8WTI
M.PH@("`@("`@("`@("!I9B`H)&]U="D@>PH@("`@("`@("`@("`@("`@8FEN
M;6]D92@D;W5T*3L*("`@("`@("`@("`@("`@('!R:6YT("1O=70@)&9I;&5N
M86UE+3Y[8G5F?3L*("`@("`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@;W!E;B!M>2`D9F@L("<\)RP@)&YA;64@
M;W(@9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@
M("`@(')E='5R;B`D9F@["B`@("`@("`@?0H*("`@("`@("!D:64@(D)O;W1S
M=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*("`@
M('TL($!)3D,I.PH*("`@(",@3F]W(&QO860@86QL(&)U;F1L960@9FEL97,@
M>WM["@H@("`@(R!I;FET:6%L:7IE('-H87)E9"!O8FIE8W0@<')O8V5S<VEN
M9PH@("`@<F5Q=6ER92!84TQO861E<CL*("`@(')E<75I<F4@4$%2.CI(96%V
M>3L*("`@(')E<75I<F4@0V%R<#HZ2&5A=GD["B`@("!R97%U:7)E($5X<&]R
M=&5R.CI(96%V>3L*("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H
M*3L*"B`@("`C(&YO=R!L970G<R!T<GD@9V5T=&EN9R!H96QP97(@;6]D=6QE
M<R!F<F]M('=I=&AI;@H@("`@<F5Q=6ER92!)3SHZ1FEL93L*"B`@("`C(&QO
M860@<F5S="!O9B!T:&4@9W)O=7`@:6X*("`@('=H:6QE("AM>2`D9FEL96YA
M;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["B`@("`@("`@
M(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-
M4U=I;C,R)SL*("`@("`@("!U;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D
M9FEL96YA;64@/7X@+T)31%!!3B\I('L*("`@("`@("`@("`@(R!R97%U:7)E
M(&UO9'5L97,L(&1O(&]T:&5R(&5X96-U=&%B;&4@9FEL97,*("`@("`@("`@
M("`@:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["B`@("`@("`@("`@
M("`@("!R97%U:7)E("1F:6QE;F%M93L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!E;'-E('L*("`@("`@("`@("`@("`@(",@4VMI<"!!8W1I=F53=&%T
M92=S('-I=&5C=7-T;VUI>F4N<&P@9FEL93H*("`@("`@("`@("`@("`@(&1O
M("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE
M7"YP;"0O.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&1E;&5T
M92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["B`@("!]"@H@("`@(R!]?7T*
M"B`@("!L87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*("`@("1S
M=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0HC('U]?0H*(R!!<F=U;65N
M="!P<F]C97-S:6YG('M[>PIM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N
M9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*"F1E;&5T92`D14Y6>U!!4E]!
M4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET
M>2!P<F]B;&5M*0H*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=]
M.PHC($1O;B=T('-W86QL;W<@87)G=6UE;G1S(&9O<B!C;VUP:6QE9"!E>&5C
M=71A8FQE<R!W:71H;W5T("TM<&%R+6]P=&EO;G,*:68@*"$D<W1A<G1?<&]S
M(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2![
M"B`@("!M>2`E9&ES=%]C;60@/2!Q=R@*("`@("`@("!P("`@8FQI8E]T;U]P
M87(*("`@("`@("!I("`@:6YS=&%L;%]P87(*("`@("`@("!U("`@=6YI;G-T
M86QL7W!A<@H@("`@("`@(',@("!S:6=N7W!A<@H@("`@("`@('8@("!V97)I
M9GE?<&%R"B`@("`I.PH*("`@(",@:68@=&AE(&%P<"!I<R!I;G9O:V5D(&%S
M(")A<'!N86UE("TM<&%R+6]P=&EO;G,@+2UR975S92!04D]'4D%-($!04D]'
M7T%21U8B+`H@("`@(R!U<V4@=&AE(&%P<"!T;R!R=6X@=&AE(&=I=F5N('!E
M<FP@8V]D92!I;G-T96%D(&]F(&%N>71H:6YG(&9R;VT@=&AE"B`@("`C(&%P
M<"!I='-E;&8@*&)U="!S=&EL;"!S970@=7`@=&AE(&YO<FUA;"!A<'`@96YV
M:7)O;FUE;G0@86YD($!)3D,I"B`@("!I9B`H0$%21U8@86YD("1!4D=66S!=
M(&5Q("<M+7)E=7-E)RD@>PH@("`@("`@('-H:69T($!!4D=6.PH@("`@("`@
M("1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*("`@('T*("`@
M(&5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@H*("`@("`@("!M>2!`
M861D7W1O7VEN8SL*("`@("`@("!W:&EL92`H0$%21U8I('L*("`@("`@("`@
M("`@)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@
M;&%S=#L*"B`@("`@("`@("`@(&EF("@D,2!E<2`G22<I('L*("`@("`@("`@
M("`@("`@('!U<V@@0&%D9%]T;U]I;F,L("0R.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&5L<VEF("@D,2!E<2`G32<I('L*("`@("`@("`@("`@("`@
M(&5V86P@(G5S92`D,B(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS
M:68@*"0Q(&5Q("=!)RD@>PH@("`@("`@("`@("`@("`@=6YS:&EF="!`<&%R
M7V%R9W,L("0R.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D
M,2!E<2`G3R<I('L*("`@("`@("`@("`@("`@("1O=70@/2`D,CL*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)V(G*2!["B`@("`@
M("`@("`@("`@("`D8G5N9&QE(#T@)W-I=&4G.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&5L<VEF("@D,2!E<2`G0B<I('L*("`@("`@("`@("`@("`@
M("1B=6YD;&4@/2`G86QL)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E
M;'-I9B`H)#$@97$@)W$G*2!["B`@("`@("`@("`@("`@("`D<75I970@/2`Q
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G3"<I
M('L*("`@("`@("`@("`@("`@(&]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D
M:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=4)RD@>PH@("`@("`@("`@("`@
M("`@)&-A8VAE7VYA;64@/2`D,CL*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@<VAI9G0H0$%21U8I.PH*("`@("`@("`@("`@:68@*&UY("1C;60@/2`D
M9&ES=%]C;61[)#%]*2!["B`@("`@("`@("`@("`@("!D96QE=&4@)$5.5GLG
M4$%27U1%35`G?3L*("`@("`@("`@("`@("`@(&EN:71?:6YC*"D["B`@("`@
M("`@("`@("`@("!R97%U:7)E(%!!4CHZ1&ES=#L*("`@("`@("`@("`@("`@
M("9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PH@("`@("`@
M("`@("`@("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*
M("`@("`@("`@("`@("`@(&5X:70["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@('5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["B`@("!]"GT*
M"B,@6%A8("TM(&%D9"`M+7!A<BUD96)U9R!S=7!P;W)T(0H*(R!]?7T*"B,@
M3W5T<'5T(&UO9&4@*"U/*2!H86YD;&EN9R![>WL*:68@*"1O=70I('L*("`@
M('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I
M9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@(')E<75I<F4@24\Z.D9I;&4[
M"B`@("`@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]"@H@("`@;7D@
M)'!A<B`]('-H:69T*$!!4D=6*3L*("`@(&UY("1Z:7`["@H*("`@(&EF("AD
M969I;F5D("1P87(I('L*("`@("`@("!O<&5N(&UY("1F:"P@)SPG+"`D<&%R
M(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["B`@("`@("`@8FEN
M;6]D92@D9F@I.PH@("`@("`@(&)L97-S*"1F:"P@)TE/.CI&:6QE)RD["@H@
M("`@("`@("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*("`@("`@("`H("1Z
M:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z
M.EII<#HZ05I?3TLH*2`I"B`@("`@("`@("`@(&]R(&1I92`B4F5A9"`G)'!A
M<B<@97)R;W(Z("0A(CL*("`@('T*"@H@("`@;7D@)65N=B`](&1O('L*("`@
M("`@("!I9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G
M345402YY;6PG*2D@>PH@("`@("`@("`@("`D;65T82`]?B!S+RXJ7G!A<CHD
M+R]M<SL*("`@("`@("`@("`@)&UE=&$@/7X@<R]>7%,N*B\O;7,["B`@("`@
M("`@("`@("1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*("`@("`@
M("!]"B`@("!].PH*("`@(",@3W!E;B!I;G!U="!A;F0@;W5T<'5T(&9I;&5S
M('M[>PH@("`@;&]C86P@)"\@/2!<-#L*"B`@("!I9B`H9&5F:6YE9"`D<&%R
M*2!["B`@("`@("`@;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D
M<&%R(CL*("`@("`@("!B:6YM;V1E*%!!4BD["B`@("`@("`@9&EE("(D<&%R
M(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP
M,#0B.PH@("`@?0H*("`@($-R96%T95!A=&@H)&]U="D@.PH@("`@"B`@("!M
M>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`H@("`@("`@("1O=70L"B`@("`@("`@
M24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@
M24\Z.D9I;&4Z.D]?5%)53D,H*2P*("`@("`@("`P-S<W+`H@("`@*2!O<B!D
M:64@)"$["B`@("!B:6YM;V1E*"1F:"D["@H@("`@)"\@/2`H9&5F:6YE9"`D
M9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PH@("`@<V5E:R!?1D@L
M(#`L(#`["B`@("!M>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PH@("`@:68@
M*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<
M0')E;2DO*2!["B`@("`@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R
M:7`["B`@("`@("`@4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY
M*%PD;&]A9&5R+"`D,"D*("`@('T*("`@(&9O<F5A8V@@;7D@)&ME>2`H<V]R
M="!K97ES("5E;G8I('L*("`@("`@("!M>2`D=F%L(#T@)&5N=GLD:V5Y?2!O
M<B!N97AT.PH@("`@("`@("1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O
M7ELG(ETO.PH@("`@("`@(&UY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C
M*"1K97DI("X@(E]?(CL*("`@("`@("!M>2`D<V5T(#T@(E!!4E\B("X@=6,H
M)&ME>2D@+B`B/21V86PB.PH@("`@("`@("1L;V%D97(@/7X@<WLD;6%G:6,H
M("LI?7L*("`@("`@("`@("`@)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N
M9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"B`@("`@("`@?65G.PH@("`@?0H@
M("`@)&9H+3YP<FEN="@D;&]A9&5R*3L*("`@("0O(#T@=6YD968["B`@("`C
M('U]?0H*("`@(",@5W)I=&4@8G5N9&QE9"!M;V1U;&5S('M[>PH@("`@:68@
M*"1B=6YD;&4I('L*("`@("`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("`@
M("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH@("`@("`@(&EN
M:71?:6YC*"D["@H@("`@("`@(')E<75I<F5?;6]D=6QE<R@I.PH*("`@("`@
M("!M>2!`:6YC(#T@<V]R="!["B`@("`@("`@("`@(&QE;F=T:"@D8BD@/#T^
M(&QE;F=T:"@D82D*("`@("`@("!](&=R97`@>PH@("`@("`@("`@("`A+T)3
M1%!!3B\*("`@("`@("!](&=R97`@>PH@("`@("`@("`@("`H)&)U;F1L92!N
M92`G<VET92<I(&]R"B`@("`@("`@("`@("@D7R!N92`D0V]N9FEG.CI#;VYF
M:6=[87)C:&QI8F5X<'T@86YD"B`@("`@("`@("`@("`D7R!N92`D0V]N9FEG
M.CI#;VYF:6=[<')I=FQI8F5X<'TI.PH@("`@("`@('T@0$E.0SL*"B`@("`@
M("`@(R!&:6QE(&5X:7-T<R!T97-T(&%D9&5D('1O(&9I>"!25"`C-#$W.3`Z
M"B`@("`@("`@(R!&=6YN>2P@;F]N+65X:7-T:6YG(&5N=')Y(&EN(%\\+BXN
M+F%U=&\O0V]M<')E<W,O4F%W+UIL:6(O875T;W-P;&ET+FEX+@H@("`@("`@
M(",@5&AI<R!I<R!A(&)A;F0M86ED(&9I>"!W:71H(&YO(&1E97!E<B!G<F%S
M<"!O9B!T:&4@:7-S=64N"B`@("`@("`@(R!3;VUE8F]D>2!P;&5A<V4@9V\@
M=&AR;W5G:"!T:&4@<&%I;B!O9B!U;F1E<G-T86YD:6YG('=H870G<R!H87!P
M96YI;F<L"B`@("`@("`@(R!)(&9A:6QE9"X@+2T@4W1E9F9E;@H@("`@("`@
M(&UY("5F:6QE<SL*("`@("`@("`O7E\\*"XK*20O(&%N9"`M92`D,2!A;F0@
M)&9I;&5S>R0Q?2LK(&9O<B!K97ES("4Z.CL*("`@("`@("`D9FEL97-[)%]]
M*RL@9F]R('9A;'5E<R`E24Y#.PH*("`@("`@("!M>2`D;&EB7V5X="`]("1#
M;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*("`@("`@("!M>2`E=W)I='1E;CL*
M"B`@("`@("`@9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PH@("`@("`@
M("`@("!M>2`H)&YA;64L("1F:6QE*3L*"B`@("`@("`@("`@(&9O<F5A8V@@
M;7D@)&1I<B`H0&EN8RD@>PH@("`@("`@("`@("`@("`@:68@*"1N86UE(#T@
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*("`@("`@("`@("`@("`@
M("`@("`D9FEL92`]("1?.PH@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-I9B`H+UXH7%$D
M9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2!["B`@("`@("`@("`@("`@("`@("`@
M*"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*("`@("`@("`@("`@("`@("`@
M("!L87-T.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@96QS
M:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["B`@("`@("`@
M("`@("`@("`@("`@:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE
M0V%C:&5[)#%]*2!["B`@("`@("`@("`@("`@("`@("`@("`@("@D9FEL92P@
M)&YA;64I(#T@*"1R968L("0Q*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M;&%S=#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@96QS:68@*"UF("(D9&ER+R0Q(BD@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`H)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M(&YE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD
M;F%M97TK*SL*("`@("`@("`@("`@;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@
M)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["B`@("`@("`@("`@(&]U=',H
M(&IO:6X@(B(L"B`@("`@("`@("`@("`@("!Q<2A086-K:6YG("(I+"!R968@
M)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"B`@("`@("`@("`@("`@
M("!Q<2@B+BXN*0H@("`@("`@("`@("`I.PH*("`@("`@("`@("`@;7D@)&-O
M;G1E;G0["B`@("`@("`@("`@(&EF("AR968H)&9I;&4I*2!["B`@("`@("`@
M("`@("`@("`D8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@(&]P96X@1DE,
M12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*
M("`@("`@("`@("`@("`@(&)I;FUO9&4H1DE,12D["B`@("`@("`@("`@("`@
M("`D8V]N=&5N="`](#Q&24Q%/CL*("`@("`@("`@("`@("`@(&-L;W-E($9)
M3$4["@H@("`@("`@("`@("`@("`@4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN
M97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I"B`@("`@("`@("`@("`@("`@
M("`@:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z
M<&U\:7A\86PI)"]I.PH*("`@("`@("`@("`@("`@(%!!4CHZ1FEL=&5R.CI0
M871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA
M;64I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!O=71S*'%Q*%=R:71T
M96X@87,@(B1N86UE(BDI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*")&24Q%
M(BD["B`@("`@("`@("`@("1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D
M;F%M92D@*R`Y*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H<W!R:6YT9B@*
M("`@("`@("`@("`@("`@("(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP
M=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90H@("`@("`@("`@("`I*3L*("`@
M("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT
M*2DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*"1C;VYT96YT*3L*("`@("`@
M("!]"B`@("!]"B`@("`C('U]?0H*("`@(",@3F]W('=R:71E(&]U="!T:&4@
M4$%2(&%N9"!M86=I8R!S=')I;F=S('M[>PH@("`@)'II<"T^=W)I=&54;T9I
M;&5(86YD;&4H)&9H*2!I9B`D>FEP.PH*("`@("1C86-H95]N86UE(#T@<W5B
M<W1R("1C86-H95]N86UE+"`P+"`T,#L*("`@(&EF("@A)&-A8VAE7VYA;64@
M86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PH@("`@("`@(&UY
M("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI3
M2$$M/FYE=R@Q*2!]"B`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I
M9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0H@("`@("`@("`@("!\
M?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE
M=R!].PH*("`@("`@("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z
M.E-(02`U+C,X(&%N9"`U+C,Y"B`@("`@("`@;7D@)'-H85]V97)S:6]N(#T@
M979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["B`@("`@("`@
M:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q
M("<U+C,Y)RD@>PH@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1O=70L(")B
M(BD@:68@*"1C='@I.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@
M("`@("`@:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PH@
M("`@("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("`@("`@
M)&-T>"T^861D9FEL92@D9F@I.PH@("`@("`@("`@("`@("`@8VQO<V4H)&9H
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&-A8VAE7VYA
M;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE.PH@("`@?0H@
M("`@)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?
M;F%M92D["B`@("`D8V%C:&5?;F%M92`N/2`B0T%#2$4B.PH@("`@)&9H+3YP
M<FEN="@D8V%C:&5?;F%M92D["B`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"`D
M9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*("`@("1F:"T^<')I;G0H
M(EQN4$%2+G!M7&XB*3L*("`@("1F:"T^8VQO<V4["B`@("!C:&UO9"`P-S4U
M+"`D;W5T.PH@("`@(R!]?7T*"B`@("!E>&ET.PI]"B,@?7U]"@HC(%!R97!A
M<F4@)'!R;V=N86UE(&EN=&\@4$%2(&9I;&4@8V%C:&4@>WM["GL*("`@(&QA
M<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*"B`@("!?9FEX7W!R;V=N
M86UE*"D["@H@("`@(R!.;W<@;&]A9"!T:&4@4$%2(&9I;&4@86YD('!U="!I
M="!I;G1O(%!!4CHZ3&EB0V%C:&4@>WM["B`@("!R97%U:7)E(%!!4CL*("`@
M(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*"@H@("`@>PH@("`@
M("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N
M92`G35-7:6XS,B<["B`@("`@("`@<F5Q=6ER92!&:6QE.CI&:6YD.PH@("`@
M("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@?0H@("`@;7D@)'II<"`]
M($%R8VAI=F4Z.EII<"T^;F5W.PH@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE
M=SL*("`@("1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B
M)"$Z("1`(CL*("`@("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P
M<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z
M("1`(CL*"B`@("!P=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PH@("`@)%!!
M4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["@H@("`@)'%U:65T(#T@
M(21%3E9[4$%27T1%0E5'?3L*("`@(&]U=',H<7$H7"1%3E9[4$%27U1%35!]
M(#T@(B1%3E9[4$%27U1%35!](BDI.PH*("`@(&EF("AD969I;F5D("1%3E9[
M4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0H@
M("`@("`@(&9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2![
M"B`@("`@("`@("`@(&YE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["B`@
M("`@("`@("`@(&UY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE
M.PH@("`@("`@("`@("!N97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*
M("`@("`@("`@("`@("`@(%X*("`@("`@("`@("`@("`@("\_<VAL:6(O"B`@
M("`@("`@("`@("`@("`H/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\*
M("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO
M*3\*("`@("`@("`@("`@("`@("A;7B]=*RD*("`@("`@("`@("`@("`@("0*
M("`@("`@("`@("`@?7@["B`@("`@("`@("`@(&UY("1E>'1R86-T7VYA;64@
M/2`D,3L*("`@("`@("`@("`@;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M
M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PH@("`@
M("`@("`@("!I9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M
M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PH@("`@("`@("`@("`@("`@;W5T<RAQ
M<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X
M:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@(&]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N
M86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*("`@("`@("`@("`@("`@("1M96UB
M97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*("`@("`@("`@
M("`@("`@(&-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U
M>"(["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"B`@("`C('U]?0I]
M"B,@?7U]"@HC($EF('1H97)E)W,@;F\@;6%I;BYP;"!T;R!R=6XL('-H;W<@
M=7-A9V4@>WM["G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@
M>PH@("`@9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!
M;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@
M6R!P<F]G<F%M+G!L(%T*("`@("`@("0P(%L@+4)\+6(@72!;+4]O=71F:6QE
M72!S<F,N<&%R"BX*("`@("1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M
M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"B,@?7U]"@IS=6(@0W)E871E4&%T
M:"!["B`@("!M>2`H)&YA;64I(#T@0%\["B`@("`*("`@(')E<75I<F4@1FEL
M93HZ0F%S96YA;64["B`@("!M>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@
M/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D[
M"B`@("`*("`@(')E<75I<F4@1FEL93HZ4&%T:#L*("`@(`H@("`@1FEL93HZ
M4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T
M:"!D:65S('=I=&@@97)R;W(*?0H*<W5B(')E<75I<F5?;6]D=6QE<R!["B`@
M("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@
M)TU35VEN,S(G.PH*("`@(')E<75I<F4@;&EB.PH@("`@<F5Q=6ER92!$>6YA
M3&]A9&5R.PH@("`@<F5Q=6ER92!I;G1E9V5R.PH@("`@<F5Q=6ER92!S=')I
M8W0["B`@("!R97%U:7)E('=A<FYI;F=S.PH@("`@<F5Q=6ER92!V87)S.PH@
M("`@<F5Q=6ER92!#87)P.PH@("`@<F5Q=6ER92!#87)P.CI(96%V>3L*("`@
M(')E<75I<F4@17)R;F\["B`@("!R97%U:7)E($5X<&]R=&5R.CI(96%V>3L*
M("`@(')E<75I<F4@17AP;W)T97(["B`@("!R97%U:7)E($9C;G1L.PH@("`@
M<F5Q=6ER92!&:6QE.CI496UP.PH@("`@<F5Q=6ER92!&:6QE.CI3<&5C.PH@
M("`@<F5Q=6ER92!84TQO861E<CL*("`@(')E<75I<F4@0V]N9FEG.PH@("`@
M<F5Q=6ER92!)3SHZ2&%N9&QE.PH@("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@
M(')E<75I<F4@0V]M<')E<W,Z.EIL:6(["B`@("!R97%U:7)E($%R8VAI=F4Z
M.EII<#L*("`@(')E<75I<F4@4$%2.PH@("`@<F5Q=6ER92!005(Z.DAE879Y
M.PH@("`@<F5Q=6ER92!005(Z.D1I<W0["B`@("!R97%U:7)E(%!!4CHZ1FEL
M=&5R.CI0;V13=')I<#L*("`@(')E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H
M0V]N=&5N=#L*("`@(')E<75I<F4@871T<FEB=71E<SL*("`@(&5V86P@>R!R
M97%U:7)E($-W9"!].PH@("`@979A;"![(')E<75I<F4@5VEN,S(@?3L*("`@
M(&5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PH@("`@979A;"![(')E
M<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["B`@("!E=F%L('L@<F5Q
M=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PH@("`@979A;"![(')E
M<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["GT*"B,@
M5&AE($,@=F5R<VEO;B!O9B!T:&ES(&-O9&4@87!P96%R<R!I;B!M>6QD<B]M
M:W1M<&1I<BYC"B,@5&AI<R!C;V1E(&%L<V\@;&EV97,@:6X@4$%2.CI3971U
M<%1E;7`@87,@<V5T7W!A<E]T96UP7V5N=B$*<W5B(%]S971?<&%R7W1E;7`@
M>PH@("`@:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%2
M7U1%35!](#U^("\H+BLI+RD@>PH@("`@("`@("1P87)?=&5M<"`]("0Q.PH@
M("`@("`@(')E='5R;CL*("`@('T*"B`@("!F;W)E86-H(&UY("1P871H("@*
M("`@("`@("`H;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@
M5$5-4$1)4B!414U0(%1-4"`I*2P*("`@("`@("!Q=R@@0SI<7%1%35`@+W1M
M<"`N("D*("`@("D@>PH@("`@("`@(&YE>'0@=6YL97-S(&1E9FEN960@)'!A
M=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*("`@("`@("!M>2`D=7-E
M<FYA;64["B`@("`@("`@;7D@)'!W=6ED.PH@("`@("`@(",@9&]E<R!N;W0@
M=V]R:R!E=F5R>7=H97)E.@H@("`@("`@(&5V86P@>R@D<'=U:60I(#T@9V5T
M<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*"B`@("`@("`@:68@*"!D969I
M;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*("`@("`@("`@("`@)'5S97)N
M86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["B`@("`@("`@?0H@("`@("`@(&5L
M<VEF("AD969I;F5D("1P=W5I9"D@>PH@("`@("`@("`@("`D=7-E<FYA;64@
M/2`D<'=U:60["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@
M("`D=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\
M("=365-414TG.PH@("`@("`@('T*("`@("`@("`D=7-E<FYA;64@/7X@<R]<
M5R]?+V<["@H@("`@("`@(&UY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?
M9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["B`@("`@("`@
M;6MD:7(@)'-T;7!D:7(L(#`W-34["B`@("`@("`@:68@*"$D14Y6>U!!4E]#
M3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2![
M"B`@("`@("`@("`@(&]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PH@
M("`@("`@("`@("!S965K("1F:"P@+3$X+"`R.PH@("`@("`@("`@("!S>7-R
M96%D("1F:"P@;7D@)&)U9BP@-CL*("`@("`@("`@("`@:68@*"1B=68@97$@
M(EPP0T%#2$4B*2!["B`@("`@("`@("`@("`@("!S965K("1F:"P@+34X+"`R
M.PH@("`@("`@("`@("`@("`@<WES<F5A9"`D9F@L("1B=68L(#0Q.PH@("`@
M("`@("`@("`@("`@)&)U9B`]?B!S+UPP+R]G.PH@("`@("`@("`@("`@("`@
M)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@
M("`@;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E
M<W0Z.E-(02T^;F5W*#$I('T*("`@("`@("`@("`@("`@("`@("!\?"!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*
M("`@("`@("`@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z
M.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PH*("`@("`@("`@("`@("`@(",@
M5V]R:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S=#HZ4TA!(#4N,S@@86YD(#4N
M,SD*("`@("`@("`@("`@("`@(&UY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D
M1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@("`@("`@("`@("`@("`@
M:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q
M("<U+C,Y)RD@>PH@("`@("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H
M)'!R;V=N86UE+"`B8B(I(&EF("@D8W1X*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(&EF
M("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@
M("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&9H*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)'-T;7!D:7(@
M+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH
M97AD:6=E<W0@.B`D;71I;64@*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!C;&]S92@D9F@I.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@
M("`@("`@)$5.5GM005)?0TQ%04Y](#T@,3L*("`@("`@("`@("`@)'-T;7!D
M:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PH@("`@("`@('T*"B`@
M("`@("`@)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*("`@("`@("!M:V1I
M<B`D<W1M<&1I<BP@,#<U-3L*("`@("`@("!L87-T.PH@("`@?0H*("`@("1P
M87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]4
M14U0?2`]?B`O*"XK*2\["GT*"G-U8B!?=&5M<&9I;&4@>PH@("`@;7D@*"1E
M>'0L("1C<F,I(#T@0%\["B`@("!M>2`H)&9H+"`D9FEL96YA;64I.PH*("`@
M("1F:6QE;F%M92`]("(D<&%R7W1E;7`O)&-R8R1E>'0B.PH*("`@(&EF("@D
M14Y6>U!!4E]#3$5!3GTI('L*("`@("`@("!U;FQI;FL@)&9I;&5N86UE(&EF
M("UE("1F:6QE;F%M93L*("`@("`@("!P=7-H($!T;7!F:6QE+"`D9FEL96YA
M;64["B`@("!]"B`@("!E;'-E('L*("`@("`@("!R971U<FX@*'5N9&5F+"`D
M9FEL96YA;64I(&EF("@M<B`D9FEL96YA;64I.PH@("`@?0H*("`@(&]P96X@
M)&9H+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["B`@("!B:6YM;V1E*"1F
M:"D["B`@("!R971U<FXH)&9H+"`D9FEL96YA;64I.PI]"@HC('-A;64@8V]D
M92!L:79E<R!I;B!005(Z.E-E='5P4')O9VYA;64Z.G-E=%]P<F]G;F%M90IS
M=6(@7W-E=%]P<F]G;F%M92!["B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]0
M4D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*
M("`@("`@("`D<')O9VYA;64@/2`D,3L*("`@('T*"B`@("`D<')O9VYA;64@
M?'P]("0P.PH*("`@(&EF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R
M;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PH@("`@("`@("1P<F]G
M;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#
M;VYF:6=[7V1E;&EM?2D@*R`Q*3L*("`@('T*"B`@("!I9B`H(21%3E9[4$%2
M7U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM
M?2D@/CT@,"D@>PH@("`@("`@(&EF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O
M9VYA;64I('L*("`@("`@("`@("`@<F5T=7)N(&EF("US("1F:#L*("`@("`@
M("!]"B`@("`@("`@:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@
M>PH@("`@("`@("`@("`D<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*("`@
M("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*("`@('T*"B`@("!F;W)E86-H
M(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6
M>U!!5$A]*2!["B`@("`@("`@;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-
M4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B`@("`@("`@)&1I<B`]
M?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B`@("`@("`@*"@D<')O9VYA
M;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X
M97TB*2P@;&%S="D*("`@("`@("`@("`@:68@+7,@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL*("`@("`@("`H*"1P<F]G
M;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I
M"B`@("`@("`@("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N
M86UE(CL*("`@('T*?0H*<W5B(%]F:7A?<')O9VYA;64@>PH@("`@)#`@/2`D
M<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*("`@(&EF("AI;F1E
M>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B`@("`@("`@
M)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PH@("`@
M?0H*("`@(",@6%A8("T@:&%C:R!T;R!M86ME(%!71"!W;W)K"B`@("!M>2`D
M<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*
M("`@("`@("`@("`@("`@(#H@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_
M(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*("`@(&-H;VUP*"1P=V0I.PH@
M("`@)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<
M12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["@H@("`@)$5.5GM005)?4%)/1TY!
M345](#T@)'!R;V=N86UE.PI]"@IS=6(@7W!A<E]I;FET7V5N=B!["B`@("!I
M9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["B`@("`@("`@
M<F5T=7)N.PH@("`@?2!E;'-E('L*("`@("`@("`D14Y6>U!!4E])3DE424%,
M25I%1'T@/2`R.PH@("`@?0H*("`@(&9O<B`H<7<H(%-005=.140@5$5-4"!#
M3$5!3B!$14)51R!#04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@>PH@
M("`@("`@(&1E;&5T92`D14Y6>R=005)?)RXD7WT["B`@("!]"B`@("!F;W(@
M*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B`@("`@("`@)$5.
M5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES
M=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*("`@('T*"B`@("!M>2`D<&%R
M7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*
M"B`@("!I9B`H)$5.5GM005)?5$5-4'TI('L*("`@("`@("!D96QE=&4@)$5.
M5GM005)?0TQ%04Y].PH@("`@?0H@("`@96QS:68@*"%E>&ES=',@)$5.5GM0
M05)?1TQ/0D%,7T-,14%.?2D@>PH@("`@("`@(&UY("1V86QU92`]('-U8G-T
M<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B`@("`@("`@
M)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%.
M/2A<4RLI+SL*("`@('T*?0H*<W5B(&]U=',@>PH@("`@<F5T=7)N(&EF("1Q
M=6EE=#L*("`@(&EF("@D;&]G9F@I('L*("`@("`@("!P<FEN="`D;&]G9F@@
M(D!?7&XB.PH@("`@?0H@("`@96QS92!["B`@("`@("`@<')I;G0@(D!?7&XB
M.PH@("`@?0I]"@IS=6(@:6YI=%]I;F,@>PH@("`@<F5Q=6ER92!#;VYF:6<[
M"B`@("!P=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O
M;F9I9WLD7WTL('%W*`H@("`@("`@(&%R8VAL:6)E>'`@<')I=FQI8F5X<"!S
M:71E87)C:&5X<"!S:71E;&EB97AP"B`@("`@("`@=F5N9&]R87)C:&5X<"!V
M96YD;W)L:6)E>'`*("`@("D["GT*"B,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(PHC(%1H92!M86EN('!A8VMA9V4@9F]R('-C<FEP="!E>&5C=71I;VX*
M"G!A8VMA9V4@;6%I;CL*"G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF
M4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*"F1I92!Q
M<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z
M($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*("`@('5N;&5S<R`M92`D
M<')O9VYA;64["@ID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D
M0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*"GT[
M"@HD.CI?7T524D]2(#T@)$`@:68@)$`["GT*"D-/4D4Z.F5X:70H)#$I(&EF
M("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z
M.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*"C$["@HC;&EN92`Q,#$Q"@I?7T5.
M1%]?"@```````````````````,!#)$9R965"4T0Z(')E;&5A<V4O."XP+C`O
M;&EB+V-S=2]A;60V-"]C<G1N+E,@,3(W,C4R(#(P,#0M,#,M,C$@,#$Z,SDZ
M,#%:('!E=&5R("0``````1O__^@+$```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````9E9```````````````````C&4```````*%A```````#_
M____`````!0``````````7I2``%X$`$##`<(D`$``"0````<````\!]``)P`
M````00X0A@)##09"C0-+@P6,!``````````4````1````)`@0``X`````$0.
M$``````4````7````-`@0``B```````````````4````=``````A0``T````
M```````````L````C````$`A0`#P%0```$(.$$8.&$(.($$.*(8%C`2-`XX"
M1`XP1PZX!(,&```D````O````#`W0`#9`````$J/`HP%7@Y`C@.-!(8&@P<`
M````````'````.0````0.$``3P````!!#A!!#AB#`X8"1PXP```4````!`$`
M`&`X0``5`````$0.(``````4````'`$``(`X0`!-`````$0.$``````4````
M-`$``-`X0``>`````$0.$``````4````3`$``/`X0`#"`````$@.$(,"```<
M````9`$``,`Y0`!"`0```$J#!HP$60ZP`8X"C0.&!1P```"$`0``$#M``$\`
M````00X0@P)'#I`!````````'````*0!``!@.T``R0````!6#L`0C`*&`X,$
M```````4````Q`$``#`\0``%```````````````T````W`$``$`\0``%`@``
M`$(.$$0.&(X#CP)%#B!"#BA!#C"&!HP%C01$#CA$#E"#!P```````#0````4
M`@``4#Y``!<!````0@X00@X8C@./`D4.($(.*(P%C01'#C!!#CA$#H`!@P>&
M!@``````%````$P"``!P/T``O@$```!$#D``````%````&0"```P04``(@``
M``!$#A``````'````'P"``!@04``X@````!!#A!!#AB#`X8"1PX@```4````
MG`(``%!"0`!M`````$X.((8"@P,<````M`(``,!"0`#P`0```$$.$$0.,(,"
M`````````#0```#4`@``L$1``*P!````0@X00@X80@X@0@XHC`6-!(X#CP))
M#C!!#CB#!X8&2@[@"0``````-`````P#``!@1D``+`H```!"#A"/`DH.&$(.
M($(.*$$.,$$..$<.H(0"@P>&!HP%C02.`P`````L````1`,``)!00`!2`P``
M`$(.$$<.&$(.($$.*$$.,$<.P`B#!H8%C`2-`XX"```4````=`,``/!30``4
M```````````````4````C`,``!!40``G`````$0.$```````````&```````
M```!>E(``7@0`0,,!PB0`0```````!0````@````0%1``"4`````2`X0@P(`
M``$``````````0`````````!`````````"P"`````````0`````````V`@``
M``````$`````````1`(````````!`````````%$"`````````0````````!U
M`@````````\`````````I0,````````,`````````.@;0```````#0``````
M``!H5$````````0`````````^`%````````%`````````.@.0```````!@``
M```````H!4````````H`````````R00````````+`````````!@`````````
M%0````````````````````,`````````&,90```````"`````````-`%````
M````%``````````'`````````!<`````````&!9````````'`````````,@4
M0```````"`````````!0`0````````D`````````&`````````#^__]O````
M`(@40```````____;P`````"`````````/#__V\`````LA-`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#__________P``````````__________\``````````````````````,10
M````````````````````````````$AQ````````B'$```````#(<0```````
M0AQ```````!2'$```````&(<0```````<AQ```````""'$```````)(<0```
M````HAQ```````"R'$```````,(<0```````TAQ```````#B'$```````/(<
M0````````AU````````2'4```````"(=0```````,AU```````!"'4``````
M`%(=0```````8AU```````!R'4```````((=0```````DAU```````"B'4``
M`````+(=0```````PAU```````#2'4```````.(=0```````\AU````````"
M'D```````!(>0```````(AY````````R'D```````$(>0```````4AY`````
M``!B'D```````'(>0```````@AY```````"2'D```````*(>0```````LAY`
M``````#"'D```````-(>0```````XAY```````#R'D````````(?0```````
M$A]````````B'T```````#(?0```````0A]```````!2'T```````&(?0```
M````<A]```````""'T```````)(?0```````HA]```````"R'T```````,(?
M0```````TA]```````#B'T`````````D1G)E94)31#H@<F5L96%S92\X+C`N
M,"]L:6(O8W-U+V-O;6UO;B]C<G1B<F%N9"YC(#$W-#(U,2`R,#`W+3$R+3`T
M(#$R.C$X.C0S6B!K:6(@)``D1G)E94)31#H@<F5L96%S92\X+C`N,"]L:6(O
M8W-U+V%M9#8T+V-R=#$N8R`Q-3$P-S(@,C`P-2TQ,"TP-R`R,CHQ,SHQ-UH@
M8F1E("0`1T-#.B`H1TY5*2`T+C(N,2`R,#`W,#<Q.2`@6T9R965"4T1=``!'
M0T,Z("A'3E4I(#0N,BXQ(#(P,#<P-S$Y("!;1G)E94)31%T``$=#0SH@*$=.
M52D@-"XR+C$@,C`P-S`W,3D@(%M&<F5E0E-$70``1T-#.B`H1TY5*2`T+C(N
M,2`R,#`W,#<Q.2`@6T9R965"4T1=```N<VAS=')T86(`+FEN=&5R<``N;F]T
M92Y!0DDM=&%G`"YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`
M+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI=``N=&5X
M=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F1A=&$`+F5H7V9R86UE
M`"YD>6YA;6EC`"YC=&]R<P`N9'1O<G,`+FIC<@`N9V]T`"YB<W,`+F-O;6UE
M;G0`````````````````````````````````````````````````````````
M```````````````````````````````````````+`````0````(`````````
MR`%```````#(`0```````!4````````````````````!````````````````
M````$P````<````"`````````.`!0```````X`$````````8````````````
M````````!````````````````````"$````%`````@````````#X`4``````
M`/@!````````+`,````````$``````````@`````````!``````````G````
M"P````(`````````*`5````````H!0```````,`)````````!0````$````(
M`````````!@`````````+P````,````"`````````.@.0```````Z`X`````
M``#)!````````````````````0```````````````````#<```#___]O`@``
M``````"R$T```````+(3````````T``````````$``````````(`````````
M`@````````!$````_O__;P(`````````B!1```````"(%````````$``````
M````!0````(````(````````````````````4P````0````"`````````,@4
M0```````R!0```````!0`0````````0`````````"``````````8````````
M`%T````$`````@`````````8%D```````!@6````````T`4````````$````
M"P````@`````````&`````````!G`````0````8`````````Z!M```````#H
M&P```````!,````````````````````$````````````````````8@````$`
M```&`````````/P;0```````_!L```````#P`P``````````````````!```
M```````0`````````&T````!````!@````````#P'T```````/`?````````
M>#0``````````````````!````````````````````!S`````0````8`````
M````:%1```````!H5`````````X````````````````````$````````````
M````````>0````$````"`````````'A40```````>%0```````#!7P``````
M````````````"````````````````````($````!`````@`````````\M$``
M`````#RT````````"`````````````````````0```````````````````"/
M`````0````,``````````,!0````````P````````"0`````````````````
M```(````````````````````E0````$````"`````````"C`4```````*,``
M``````#8`P``````````````````"````````````````````)\````&````
M`P``````````Q%````````#$````````\`$````````%``````````@`````
M````$`````````"H`````0````,`````````\,50``````#PQ0```````!``
M```````````````````(````````````````````KP````$````#````````
M``#&4````````,8````````0````````````````````"```````````````
M`````+8````!`````P`````````0QE```````!#&````````"```````````
M``````````@```````````````````"[`````0````,`````````&,90````
M```8Q@````````@"```````````````````(``````````@`````````P```
M``@````#`````````"#(4```````(,@````````(!0``````````````````
M(````````````````````,4````!`````````````````````````"#(````
M````.P$```````````````````$````````````````````!`````P``````
M``````````````````!;R0```````,X````````````````````!````````
)````````````
